from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.create_flow_json_body_schema import CreateFlowJsonBodySchema
from ..models.create_flow_json_body_value import CreateFlowJsonBodyValue
from ..types import UNSET, Unset

T = TypeVar("T", bound="CreateFlowJsonBody")


@attr.s(auto_attribs=True)
class CreateFlowJsonBody:
    """ """

    path: str
    summary: str
    description: str
    value: CreateFlowJsonBodyValue
    schema: Union[Unset, CreateFlowJsonBodySchema] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        summary = self.summary
        description = self.description
        value = self.value.to_dict()

        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "summary": summary,
                "description": description,
                "value": value,
            }
        )
        if schema is not UNSET:
            field_dict["schema"] = schema

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        summary = d.pop("summary")

        description = d.pop("description")

        value = CreateFlowJsonBodyValue.from_dict(d.pop("value"))

        schema: Union[Unset, CreateFlowJsonBodySchema] = UNSET
        _schema = d.pop("schema", UNSET)
        if not isinstance(_schema, Unset):
            schema = CreateFlowJsonBodySchema.from_dict(_schema)

        create_flow_json_body = cls(
            path=path,
            summary=summary,
            description=description,
            value=value,
            schema=schema,
        )

        create_flow_json_body.additional_properties = d
        return create_flow_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="TruncatedToken")


@attr.s(auto_attribs=True)
class TruncatedToken:
    """ """

    token_prefix: str
    created_at: datetime.datetime
    last_used_at: datetime.datetime
    label: Union[Unset, str] = UNSET
    expiration: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        token_prefix = self.token_prefix
        created_at = self.created_at.isoformat()

        last_used_at = self.last_used_at.isoformat()

        label = self.label
        expiration: Union[Unset, str] = UNSET
        if not isinstance(self.expiration, Unset):
            expiration = self.expiration.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "token_prefix": token_prefix,
                "created_at": created_at,
                "last_used_at": last_used_at,
            }
        )
        if label is not UNSET:
            field_dict["label"] = label
        if expiration is not UNSET:
            field_dict["expiration"] = expiration

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        token_prefix = d.pop("token_prefix")

        created_at = isoparse(d.pop("created_at"))

        last_used_at = isoparse(d.pop("last_used_at"))

        label = d.pop("label", UNSET)

        expiration: Union[Unset, datetime.datetime] = UNSET
        _expiration = d.pop("expiration", UNSET)
        if not isinstance(_expiration, Unset):
            expiration = isoparse(_expiration)

        truncated_token = cls(
            token_prefix=token_prefix,
            created_at=created_at,
            last_used_at=last_used_at,
            label=label,
            expiration=expiration,
        )

        truncated_token.additional_properties = d
        return truncated_token

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.completed_job_args import CompletedJobArgs
from ..models.completed_job_flow_status import CompletedJobFlowStatus
from ..models.completed_job_job_kind import CompletedJobJobKind
from ..models.completed_job_language import CompletedJobLanguage
from ..models.completed_job_raw_flow import CompletedJobRawFlow
from ..models.completed_job_result import CompletedJobResult
from ..types import UNSET, Unset

T = TypeVar("T", bound="CompletedJob")


@attr.s(auto_attribs=True)
class CompletedJob:
    """ """

    id: str
    created_by: str
    created_at: datetime.datetime
    started_at: datetime.datetime
    duration: int
    success: bool
    canceled: bool
    job_kind: CompletedJobJobKind
    permissioned_as: str
    is_flow_step: bool
    workspace_id: Union[Unset, str] = UNSET
    parent_job: Union[Unset, str] = UNSET
    script_path: Union[Unset, str] = UNSET
    script_hash: Union[Unset, str] = UNSET
    args: Union[Unset, CompletedJobArgs] = UNSET
    result: Union[Unset, CompletedJobResult] = UNSET
    logs: Union[Unset, str] = UNSET
    deleted: Union[Unset, bool] = UNSET
    raw_code: Union[Unset, str] = UNSET
    canceled_by: Union[Unset, str] = UNSET
    canceled_reason: Union[Unset, str] = UNSET
    schedule_path: Union[Unset, str] = UNSET
    flow_status: Union[Unset, CompletedJobFlowStatus] = UNSET
    raw_flow: Union[Unset, CompletedJobRawFlow] = UNSET
    language: Union[Unset, CompletedJobLanguage] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        created_by = self.created_by
        created_at = self.created_at.isoformat()

        started_at = self.started_at.isoformat()

        duration = self.duration
        success = self.success
        canceled = self.canceled
        job_kind = self.job_kind.value

        permissioned_as = self.permissioned_as
        is_flow_step = self.is_flow_step
        workspace_id = self.workspace_id
        parent_job = self.parent_job
        script_path = self.script_path
        script_hash = self.script_hash
        args: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.args, Unset):
            args = self.args.to_dict()

        result: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.result, Unset):
            result = self.result.to_dict()

        logs = self.logs
        deleted = self.deleted
        raw_code = self.raw_code
        canceled_by = self.canceled_by
        canceled_reason = self.canceled_reason
        schedule_path = self.schedule_path
        flow_status: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.flow_status, Unset):
            flow_status = self.flow_status.to_dict()

        raw_flow: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.raw_flow, Unset):
            raw_flow = self.raw_flow.to_dict()

        language: Union[Unset, str] = UNSET
        if not isinstance(self.language, Unset):
            language = self.language.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "created_by": created_by,
                "created_at": created_at,
                "started_at": started_at,
                "duration": duration,
                "success": success,
                "canceled": canceled,
                "job_kind": job_kind,
                "permissioned_as": permissioned_as,
                "is_flow_step": is_flow_step,
            }
        )
        if workspace_id is not UNSET:
            field_dict["workspace_id"] = workspace_id
        if parent_job is not UNSET:
            field_dict["parent_job"] = parent_job
        if script_path is not UNSET:
            field_dict["script_path"] = script_path
        if script_hash is not UNSET:
            field_dict["script_hash"] = script_hash
        if args is not UNSET:
            field_dict["args"] = args
        if result is not UNSET:
            field_dict["result"] = result
        if logs is not UNSET:
            field_dict["logs"] = logs
        if deleted is not UNSET:
            field_dict["deleted"] = deleted
        if raw_code is not UNSET:
            field_dict["raw_code"] = raw_code
        if canceled_by is not UNSET:
            field_dict["canceled_by"] = canceled_by
        if canceled_reason is not UNSET:
            field_dict["canceled_reason"] = canceled_reason
        if schedule_path is not UNSET:
            field_dict["schedule_path"] = schedule_path
        if flow_status is not UNSET:
            field_dict["flow_status"] = flow_status
        if raw_flow is not UNSET:
            field_dict["raw_flow"] = raw_flow
        if language is not UNSET:
            field_dict["language"] = language

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        created_by = d.pop("created_by")

        created_at = isoparse(d.pop("created_at"))

        started_at = isoparse(d.pop("started_at"))

        duration = d.pop("duration")

        success = d.pop("success")

        canceled = d.pop("canceled")

        job_kind = CompletedJobJobKind(d.pop("job_kind"))

        permissioned_as = d.pop("permissioned_as")

        is_flow_step = d.pop("is_flow_step")

        workspace_id = d.pop("workspace_id", UNSET)

        parent_job = d.pop("parent_job", UNSET)

        script_path = d.pop("script_path", UNSET)

        script_hash = d.pop("script_hash", UNSET)

        args: Union[Unset, CompletedJobArgs] = UNSET
        _args = d.pop("args", UNSET)
        if not isinstance(_args, Unset):
            args = CompletedJobArgs.from_dict(_args)

        result: Union[Unset, CompletedJobResult] = UNSET
        _result = d.pop("result", UNSET)
        if not isinstance(_result, Unset):
            result = CompletedJobResult.from_dict(_result)

        logs = d.pop("logs", UNSET)

        deleted = d.pop("deleted", UNSET)

        raw_code = d.pop("raw_code", UNSET)

        canceled_by = d.pop("canceled_by", UNSET)

        canceled_reason = d.pop("canceled_reason", UNSET)

        schedule_path = d.pop("schedule_path", UNSET)

        flow_status: Union[Unset, CompletedJobFlowStatus] = UNSET
        _flow_status = d.pop("flow_status", UNSET)
        if not isinstance(_flow_status, Unset):
            flow_status = CompletedJobFlowStatus.from_dict(_flow_status)

        raw_flow: Union[Unset, CompletedJobRawFlow] = UNSET
        _raw_flow = d.pop("raw_flow", UNSET)
        if not isinstance(_raw_flow, Unset):
            raw_flow = CompletedJobRawFlow.from_dict(_raw_flow)

        language: Union[Unset, CompletedJobLanguage] = UNSET
        _language = d.pop("language", UNSET)
        if not isinstance(_language, Unset):
            language = CompletedJobLanguage(_language)

        completed_job = cls(
            id=id,
            created_by=created_by,
            created_at=created_at,
            started_at=started_at,
            duration=duration,
            success=success,
            canceled=canceled,
            job_kind=job_kind,
            permissioned_as=permissioned_as,
            is_flow_step=is_flow_step,
            workspace_id=workspace_id,
            parent_job=parent_job,
            script_path=script_path,
            script_hash=script_hash,
            args=args,
            result=result,
            logs=logs,
            deleted=deleted,
            raw_code=raw_code,
            canceled_by=canceled_by,
            canceled_reason=canceled_reason,
            schedule_path=schedule_path,
            flow_status=flow_status,
            raw_flow=raw_flow,
            language=language,
        )

        completed_job.additional_properties = d
        return completed_job

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CreateFlowJsonBodyValueModulesItemInputTransformAdditionalPropertyType(str, Enum):
    STATIC = "static"
    JAVASCRIPT = "javascript"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="NewToken")


@attr.s(auto_attribs=True)
class NewToken:
    """ """

    label: Union[Unset, str] = UNSET
    expiration: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        expiration: Union[Unset, str] = UNSET
        if not isinstance(self.expiration, Unset):
            expiration = self.expiration.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if label is not UNSET:
            field_dict["label"] = label
        if expiration is not UNSET:
            field_dict["expiration"] = expiration

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        label = d.pop("label", UNSET)

        expiration: Union[Unset, datetime.datetime] = UNSET
        _expiration = d.pop("expiration", UNSET)
        if not isinstance(_expiration, Unset):
            expiration = isoparse(_expiration)

        new_token = cls(
            label=label,
            expiration=expiration,
        )

        new_token.additional_properties = d
        return new_token

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="WorkspaceInvite")


@attr.s(auto_attribs=True)
class WorkspaceInvite:
    """ """

    workspace_id: str
    email: str
    is_admin: bool
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        workspace_id = self.workspace_id
        email = self.email
        is_admin = self.is_admin

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "workspace_id": workspace_id,
                "email": email,
                "is_admin": is_admin,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        workspace_id = d.pop("workspace_id")

        email = d.pop("email")

        is_admin = d.pop("is_admin")

        workspace_invite = cls(
            workspace_id=workspace_id,
            email=email,
            is_admin=is_admin,
        )

        workspace_invite.additional_properties = d
        return workspace_invite

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GetCompletedJobResponse200FlowStatusModulesItemType(str, Enum):
    WAITINGFORPRIORSTEPS = "WaitingForPriorSteps"
    WAITINGFOREVENT = "WaitingForEvent"
    WAITINGFOREXECUTOR = "WaitingForExecutor"
    INPROGRESS = "InProgress"
    SUCCESS = "Success"
    FAILURE = "Failure"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.edit_schedule_args import EditScheduleArgs

T = TypeVar("T", bound="EditSchedule")


@attr.s(auto_attribs=True)
class EditSchedule:
    """ """

    schedule: str
    script_path: str
    is_flow: bool
    args: EditScheduleArgs
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        schedule = self.schedule
        script_path = self.script_path
        is_flow = self.is_flow
        args = self.args.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "schedule": schedule,
                "script_path": script_path,
                "is_flow": is_flow,
                "args": args,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        schedule = d.pop("schedule")

        script_path = d.pop("script_path")

        is_flow = d.pop("is_flow")

        args = EditScheduleArgs.from_dict(d.pop("args"))

        edit_schedule = cls(
            schedule=schedule,
            script_path=script_path,
            is_flow=is_flow,
            args=args,
        )

        edit_schedule.additional_properties = d
        return edit_schedule

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.run_script_preview_json_body_args import RunScriptPreviewJsonBodyArgs
from ..models.run_script_preview_json_body_language import RunScriptPreviewJsonBodyLanguage
from ..types import UNSET, Unset

T = TypeVar("T", bound="RunScriptPreviewJsonBody")


@attr.s(auto_attribs=True)
class RunScriptPreviewJsonBody:
    """ """

    content: str
    args: RunScriptPreviewJsonBodyArgs
    language: RunScriptPreviewJsonBodyLanguage
    path: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        content = self.content
        args = self.args.to_dict()

        language = self.language.value

        path = self.path

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "content": content,
                "args": args,
                "language": language,
            }
        )
        if path is not UNSET:
            field_dict["path"] = path

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        content = d.pop("content")

        args = RunScriptPreviewJsonBodyArgs.from_dict(d.pop("args"))

        language = RunScriptPreviewJsonBodyLanguage(d.pop("language"))

        path = d.pop("path", UNSET)

        run_script_preview_json_body = cls(
            content=content,
            args=args,
            language=language,
            path=path,
        )

        run_script_preview_json_body.additional_properties = d
        return run_script_preview_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.listable_variable_extra_perms import ListableVariableExtraPerms
from ..types import UNSET, Unset

T = TypeVar("T", bound="ListableVariable")


@attr.s(auto_attribs=True)
class ListableVariable:
    """ """

    workspace_id: str
    path: str
    is_secret: bool
    extra_perms: ListableVariableExtraPerms
    value: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    account: Union[Unset, str] = UNSET
    is_oauth: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        workspace_id = self.workspace_id
        path = self.path
        is_secret = self.is_secret
        extra_perms = self.extra_perms.to_dict()

        value = self.value
        description = self.description
        account = self.account
        is_oauth = self.is_oauth

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "workspace_id": workspace_id,
                "path": path,
                "is_secret": is_secret,
                "extra_perms": extra_perms,
            }
        )
        if value is not UNSET:
            field_dict["value"] = value
        if description is not UNSET:
            field_dict["description"] = description
        if account is not UNSET:
            field_dict["account"] = account
        if is_oauth is not UNSET:
            field_dict["is_oauth"] = is_oauth

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        workspace_id = d.pop("workspace_id")

        path = d.pop("path")

        is_secret = d.pop("is_secret")

        extra_perms = ListableVariableExtraPerms.from_dict(d.pop("extra_perms"))

        value = d.pop("value", UNSET)

        description = d.pop("description", UNSET)

        account = d.pop("account", UNSET)

        is_oauth = d.pop("is_oauth", UNSET)

        listable_variable = cls(
            workspace_id=workspace_id,
            path=path,
            is_secret=is_secret,
            extra_perms=extra_perms,
            value=value,
            description=description,
            account=account,
            is_oauth=is_oauth,
        )

        listable_variable.additional_properties = d
        return listable_variable

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.python_to_jsonschema_response_200_args_item_typ_type_0 import (
    PythonToJsonschemaResponse200ArgsItemTypType0,
)
from ..models.python_to_jsonschema_response_200_args_item_typ_type_1 import (
    PythonToJsonschemaResponse200ArgsItemTypType1,
)
from ..models.python_to_jsonschema_response_200_args_item_typ_type_2 import (
    PythonToJsonschemaResponse200ArgsItemTypType2,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PythonToJsonschemaResponse200ArgsItem")


@attr.s(auto_attribs=True)
class PythonToJsonschemaResponse200ArgsItem:
    """ """

    name: str
    typ: Union[
        PythonToJsonschemaResponse200ArgsItemTypType0,
        PythonToJsonschemaResponse200ArgsItemTypType1,
        PythonToJsonschemaResponse200ArgsItemTypType2,
    ]
    has_default: Union[Unset, bool] = UNSET
    default: Union[Unset, None] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        if isinstance(self.typ, PythonToJsonschemaResponse200ArgsItemTypType0):
            typ = self.typ.value

        elif isinstance(self.typ, PythonToJsonschemaResponse200ArgsItemTypType1):
            typ = self.typ.to_dict()

        else:
            typ = self.typ.to_dict()

        has_default = self.has_default
        default = None

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "typ": typ,
            }
        )
        if has_default is not UNSET:
            field_dict["has_default"] = has_default
        if default is not UNSET:
            field_dict["default"] = default

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        def _parse_typ(
            data: object,
        ) -> Union[
            PythonToJsonschemaResponse200ArgsItemTypType0,
            PythonToJsonschemaResponse200ArgsItemTypType1,
            PythonToJsonschemaResponse200ArgsItemTypType2,
        ]:
            try:
                typ_type_0: PythonToJsonschemaResponse200ArgsItemTypType0
                if not isinstance(data, str):
                    raise TypeError()
                typ_type_0 = PythonToJsonschemaResponse200ArgsItemTypType0(data)

                return typ_type_0
            except:  # noqa: E722
                pass
            try:
                typ_type_1: PythonToJsonschemaResponse200ArgsItemTypType1
                if not isinstance(data, dict):
                    raise TypeError()
                typ_type_1 = PythonToJsonschemaResponse200ArgsItemTypType1.from_dict(data)

                return typ_type_1
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            typ_type_2: PythonToJsonschemaResponse200ArgsItemTypType2
            typ_type_2 = PythonToJsonschemaResponse200ArgsItemTypType2.from_dict(data)

            return typ_type_2

        typ = _parse_typ(d.pop("typ"))

        has_default = d.pop("has_default", UNSET)

        default = None

        python_to_jsonschema_response_200_args_item = cls(
            name=name,
            typ=typ,
            has_default=has_default,
            default=default,
        )

        python_to_jsonschema_response_200_args_item.additional_properties = d
        return python_to_jsonschema_response_200_args_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ListQueueResponse200ItemRawFlowFailureModuleValueLanguage(str, Enum):
    DENO = "deno"
    PYTHON3 = "python3"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.create_schedule_json_body_args import CreateScheduleJsonBodyArgs
from ..types import UNSET, Unset

T = TypeVar("T", bound="CreateScheduleJsonBody")


@attr.s(auto_attribs=True)
class CreateScheduleJsonBody:
    """ """

    path: str
    schedule: str
    script_path: str
    is_flow: bool
    args: CreateScheduleJsonBodyArgs
    offset: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        schedule = self.schedule
        script_path = self.script_path
        is_flow = self.is_flow
        args = self.args.to_dict()

        offset = self.offset

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "schedule": schedule,
                "script_path": script_path,
                "is_flow": is_flow,
                "args": args,
            }
        )
        if offset is not UNSET:
            field_dict["offset"] = offset

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        schedule = d.pop("schedule")

        script_path = d.pop("script_path")

        is_flow = d.pop("is_flow")

        args = CreateScheduleJsonBodyArgs.from_dict(d.pop("args"))

        offset = d.pop("offset", UNSET)

        create_schedule_json_body = cls(
            path=path,
            schedule=schedule,
            script_path=script_path,
            is_flow=is_flow,
            args=args,
            offset=offset,
        )

        create_schedule_json_body.additional_properties = d
        return create_schedule_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

T = TypeVar("T", bound="WorkerPing")


@attr.s(auto_attribs=True)
class WorkerPing:
    """ """

    worker: str
    worker_instance: str
    ping_at: datetime.datetime
    started_at: datetime.datetime
    ip: str
    jobs_executed: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        worker = self.worker
        worker_instance = self.worker_instance
        ping_at = self.ping_at.isoformat()

        started_at = self.started_at.isoformat()

        ip = self.ip
        jobs_executed = self.jobs_executed

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "worker": worker,
                "worker_instance": worker_instance,
                "ping_at": ping_at,
                "started_at": started_at,
                "ip": ip,
                "jobs_executed": jobs_executed,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        worker = d.pop("worker")

        worker_instance = d.pop("worker_instance")

        ping_at = isoparse(d.pop("ping_at"))

        started_at = isoparse(d.pop("started_at"))

        ip = d.pop("ip")

        jobs_executed = d.pop("jobs_executed")

        worker_ping = cls(
            worker=worker,
            worker_instance=worker_instance,
            ping_at=ping_at,
            started_at=started_at,
            ip=ip,
            jobs_executed=jobs_executed,
        )

        worker_ping.additional_properties = d
        return worker_ping

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ListAuditLogsActionKind(str, Enum):
    CREATE = "Create"
    UPDATE = "Update"
    DELETE = "Delete"
    EXECUTE = "Execute"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.schedule_args import ScheduleArgs
from ..models.schedule_extra_perms import ScheduleExtraPerms
from ..types import UNSET, Unset

T = TypeVar("T", bound="Schedule")


@attr.s(auto_attribs=True)
class Schedule:
    """ """

    path: str
    edited_by: str
    edited_at: datetime.datetime
    schedule: str
    offset: int
    script_path: str
    is_flow: bool
    extra_perms: ScheduleExtraPerms
    enabled: Union[Unset, bool] = UNSET
    args: Union[Unset, ScheduleArgs] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        edited_by = self.edited_by
        edited_at = self.edited_at.isoformat()

        schedule = self.schedule
        offset = self.offset
        script_path = self.script_path
        is_flow = self.is_flow
        extra_perms = self.extra_perms.to_dict()

        enabled = self.enabled
        args: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.args, Unset):
            args = self.args.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "edited_by": edited_by,
                "edited_at": edited_at,
                "schedule": schedule,
                "offset_": offset,
                "script_path": script_path,
                "is_flow": is_flow,
                "extra_perms": extra_perms,
            }
        )
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if args is not UNSET:
            field_dict["args"] = args

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        edited_by = d.pop("edited_by")

        edited_at = isoparse(d.pop("edited_at"))

        schedule = d.pop("schedule")

        offset = d.pop("offset_")

        script_path = d.pop("script_path")

        is_flow = d.pop("is_flow")

        extra_perms = ScheduleExtraPerms.from_dict(d.pop("extra_perms"))

        enabled = d.pop("enabled", UNSET)

        args: Union[Unset, ScheduleArgs] = UNSET
        _args = d.pop("args", UNSET)
        if not isinstance(_args, Unset):
            args = ScheduleArgs.from_dict(_args)

        schedule = cls(
            path=path,
            edited_by=edited_by,
            edited_at=edited_at,
            schedule=schedule,
            offset=offset,
            script_path=script_path,
            is_flow=is_flow,
            extra_perms=extra_perms,
            enabled=enabled,
            args=args,
        )

        schedule.additional_properties = d
        return schedule

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.flow_extra_perms import FlowExtraPerms
from ..models.flow_schema import FlowSchema
from ..models.flow_value import FlowValue
from ..types import UNSET, Unset

T = TypeVar("T", bound="Flow")


@attr.s(auto_attribs=True)
class Flow:
    """ """

    path: str
    summary: str
    value: FlowValue
    edited_by: str
    edited_at: datetime.datetime
    archived: bool
    extra_perms: FlowExtraPerms
    workspace_id: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    schema: Union[Unset, FlowSchema] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        summary = self.summary
        value = self.value.to_dict()

        edited_by = self.edited_by
        edited_at = self.edited_at.isoformat()

        archived = self.archived
        extra_perms = self.extra_perms.to_dict()

        workspace_id = self.workspace_id
        description = self.description
        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "summary": summary,
                "value": value,
                "edited_by": edited_by,
                "edited_at": edited_at,
                "archived": archived,
                "extra_perms": extra_perms,
            }
        )
        if workspace_id is not UNSET:
            field_dict["workspace_id"] = workspace_id
        if description is not UNSET:
            field_dict["description"] = description
        if schema is not UNSET:
            field_dict["schema"] = schema

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        summary = d.pop("summary")

        value = FlowValue.from_dict(d.pop("value"))

        edited_by = d.pop("edited_by")

        edited_at = isoparse(d.pop("edited_at"))

        archived = d.pop("archived")

        extra_perms = FlowExtraPerms.from_dict(d.pop("extra_perms"))

        workspace_id = d.pop("workspace_id", UNSET)

        description = d.pop("description", UNSET)

        schema: Union[Unset, FlowSchema] = UNSET
        _schema = d.pop("schema", UNSET)
        if not isinstance(_schema, Unset):
            schema = FlowSchema.from_dict(_schema)

        flow = cls(
            path=path,
            summary=summary,
            value=value,
            edited_by=edited_by,
            edited_at=edited_at,
            archived=archived,
            extra_perms=extra_perms,
            workspace_id=workspace_id,
            description=description,
            schema=schema,
        )

        flow.additional_properties = d
        return flow

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.get_audit_log_response_200_action_kind import GetAuditLogResponse200ActionKind
from ..models.get_audit_log_response_200_operation import GetAuditLogResponse200Operation
from ..models.get_audit_log_response_200_parameters import GetAuditLogResponse200Parameters
from ..types import UNSET, Unset

T = TypeVar("T", bound="GetAuditLogResponse200")


@attr.s(auto_attribs=True)
class GetAuditLogResponse200:
    """ """

    id: int
    timestamp: datetime.datetime
    username: str
    operation: GetAuditLogResponse200Operation
    action_kind: GetAuditLogResponse200ActionKind
    resource: Union[Unset, str] = UNSET
    parameters: Union[Unset, GetAuditLogResponse200Parameters] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        timestamp = self.timestamp.isoformat()

        username = self.username
        operation = self.operation.value

        action_kind = self.action_kind.value

        resource = self.resource
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "timestamp": timestamp,
                "username": username,
                "operation": operation,
                "action_kind": action_kind,
            }
        )
        if resource is not UNSET:
            field_dict["resource"] = resource
        if parameters is not UNSET:
            field_dict["parameters"] = parameters

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        timestamp = isoparse(d.pop("timestamp"))

        username = d.pop("username")

        operation = GetAuditLogResponse200Operation(d.pop("operation"))

        action_kind = GetAuditLogResponse200ActionKind(d.pop("action_kind"))

        resource = d.pop("resource", UNSET)

        parameters: Union[Unset, GetAuditLogResponse200Parameters] = UNSET
        _parameters = d.pop("parameters", UNSET)
        if not isinstance(_parameters, Unset):
            parameters = GetAuditLogResponse200Parameters.from_dict(_parameters)

        get_audit_log_response_200 = cls(
            id=id,
            timestamp=timestamp,
            username=username,
            operation=operation,
            action_kind=action_kind,
            resource=resource,
            parameters=parameters,
        )

        get_audit_log_response_200.additional_properties = d
        return get_audit_log_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UpdateResourceTypeJsonBody")


@attr.s(auto_attribs=True)
class UpdateResourceTypeJsonBody:
    """ """

    schema: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        schema = self.schema
        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schema is not UNSET:
            field_dict["schema"] = schema
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        schema = d.pop("schema", UNSET)

        description = d.pop("description", UNSET)

        update_resource_type_json_body = cls(
            schema=schema,
            description=description,
        )

        update_resource_type_json_body.additional_properties = d
        return update_resource_type_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, Union

import httpx

from ...client import Client
from ...models.run_script_by_path_json_body import RunScriptByPathJsonBody
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    workspace: str,
    path: str,
    json_body: RunScriptByPathJsonBody,
    scheduled_for: Union[Unset, datetime.datetime] = UNSET,
    scheduled_in_secs: Union[Unset, float] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/w/{workspace}/jobs/run/p/{path}".format(client.base_url, workspace=workspace, path=path)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_scheduled_for: Union[Unset, str] = UNSET
    if not isinstance(scheduled_for, Unset):
        json_scheduled_for = scheduled_for.isoformat()

    params: Dict[str, Any] = {
        "scheduled_for": json_scheduled_for,
        "scheduled_in_secs": scheduled_in_secs,
        "parent_job": parent_job,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _build_response(*, response: httpx.Response) -> Response[None]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    workspace: str,
    path: str,
    json_body: RunScriptByPathJsonBody,
    scheduled_for: Union[Unset, datetime.datetime] = UNSET,
    scheduled_in_secs: Union[Unset, float] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
) -> Response[None]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        path=path,
        json_body=json_body,
        scheduled_for=scheduled_for,
        scheduled_in_secs=scheduled_in_secs,
        parent_job=parent_job,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    workspace: str,
    path: str,
    json_body: RunScriptByPathJsonBody,
    scheduled_for: Union[Unset, datetime.datetime] = UNSET,
    scheduled_in_secs: Union[Unset, float] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
) -> Response[None]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        path=path,
        json_body=json_body,
        scheduled_for=scheduled_for,
        scheduled_in_secs=scheduled_in_secs,
        parent_job=parent_job,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.get_flow_by_path_response_200_value_modules_item_input_transform import (
    GetFlowByPathResponse200ValueModulesItemInputTransform,
)
from ..models.get_flow_by_path_response_200_value_modules_item_value import (
    GetFlowByPathResponse200ValueModulesItemValue,
)

T = TypeVar("T", bound="GetFlowByPathResponse200ValueModulesItem")


@attr.s(auto_attribs=True)
class GetFlowByPathResponse200ValueModulesItem:
    """ """

    input_transform: GetFlowByPathResponse200ValueModulesItemInputTransform
    value: GetFlowByPathResponse200ValueModulesItemValue
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        input_transform = self.input_transform.to_dict()

        value = self.value.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "input_transform": input_transform,
                "value": value,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        input_transform = GetFlowByPathResponse200ValueModulesItemInputTransform.from_dict(d.pop("input_transform"))

        value = GetFlowByPathResponse200ValueModulesItemValue.from_dict(d.pop("value"))

        get_flow_by_path_response_200_value_modules_item = cls(
            input_transform=input_transform,
            value=value,
        )

        get_flow_by_path_response_200_value_modules_item.additional_properties = d
        return get_flow_by_path_response_200_value_modules_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.queued_job_raw_flow_failure_module_input_transform_additional_property_type import (
    QueuedJobRawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="QueuedJobRawFlowFailureModuleInputTransformAdditionalProperty")


@attr.s(auto_attribs=True)
class QueuedJobRawFlowFailureModuleInputTransformAdditionalProperty:
    """ """

    type: Union[Unset, QueuedJobRawFlowFailureModuleInputTransformAdditionalPropertyType] = UNSET
    step: Union[Unset, float] = UNSET
    value: Union[Unset, None] = UNSET
    expr: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        step = self.step
        value = None

        expr = self.expr

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if type is not UNSET:
            field_dict["type"] = type
        if step is not UNSET:
            field_dict["step"] = step
        if value is not UNSET:
            field_dict["value"] = value
        if expr is not UNSET:
            field_dict["expr"] = expr

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type: Union[Unset, QueuedJobRawFlowFailureModuleInputTransformAdditionalPropertyType] = UNSET
        _type = d.pop("type", UNSET)
        if not isinstance(_type, Unset):
            type = QueuedJobRawFlowFailureModuleInputTransformAdditionalPropertyType(_type)

        step = d.pop("step", UNSET)

        value = None

        expr = d.pop("expr", UNSET)

        queued_job_raw_flow_failure_module_input_transform_additional_property = cls(
            type=type,
            step=step,
            value=value,
            expr=expr,
        )

        queued_job_raw_flow_failure_module_input_transform_additional_property.additional_properties = d
        return queued_job_raw_flow_failure_module_input_transform_additional_property

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="GetSettingsResponse200")


@attr.s(auto_attribs=True)
class GetSettingsResponse200:
    """ """

    workspace_id: Union[Unset, str] = UNSET
    slack_name: Union[Unset, str] = UNSET
    slack_team_id: Union[Unset, str] = UNSET
    slack_command_script: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        workspace_id = self.workspace_id
        slack_name = self.slack_name
        slack_team_id = self.slack_team_id
        slack_command_script = self.slack_command_script

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if workspace_id is not UNSET:
            field_dict["workspace_id"] = workspace_id
        if slack_name is not UNSET:
            field_dict["slack_name"] = slack_name
        if slack_team_id is not UNSET:
            field_dict["slack_team_id"] = slack_team_id
        if slack_command_script is not UNSET:
            field_dict["slack_command_script"] = slack_command_script

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        workspace_id = d.pop("workspace_id", UNSET)

        slack_name = d.pop("slack_name", UNSET)

        slack_team_id = d.pop("slack_team_id", UNSET)

        slack_command_script = d.pop("slack_command_script", UNSET)

        get_settings_response_200 = cls(
            workspace_id=workspace_id,
            slack_name=slack_name,
            slack_team_id=slack_team_id,
            slack_command_script=slack_command_script,
        )

        get_settings_response_200.additional_properties = d
        return get_settings_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GetCompletedJobResponse200JobKind(str, Enum):
    SCRIPT = "script"
    PREVIEW = "preview"
    DEPENDENCIES = "dependencies"
    FLOW = "flow"
    FLOWPREVIEW = "flowpreview"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.list_resource_response_200_item_extra_perms import ListResourceResponse200ItemExtraPerms
from ..models.list_resource_response_200_item_value import ListResourceResponse200ItemValue
from ..types import UNSET, Unset

T = TypeVar("T", bound="ListResourceResponse200Item")


@attr.s(auto_attribs=True)
class ListResourceResponse200Item:
    """ """

    path: str
    resource_type: str
    is_oauth: bool
    workspace_id: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    value: Union[Unset, ListResourceResponse200ItemValue] = UNSET
    extra_perms: Union[Unset, ListResourceResponse200ItemExtraPerms] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        resource_type = self.resource_type
        is_oauth = self.is_oauth
        workspace_id = self.workspace_id
        description = self.description
        value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.value, Unset):
            value = self.value.to_dict()

        extra_perms: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.extra_perms, Unset):
            extra_perms = self.extra_perms.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "resource_type": resource_type,
                "is_oauth": is_oauth,
            }
        )
        if workspace_id is not UNSET:
            field_dict["workspace_id"] = workspace_id
        if description is not UNSET:
            field_dict["description"] = description
        if value is not UNSET:
            field_dict["value"] = value
        if extra_perms is not UNSET:
            field_dict["extra_perms"] = extra_perms

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        resource_type = d.pop("resource_type")

        is_oauth = d.pop("is_oauth")

        workspace_id = d.pop("workspace_id", UNSET)

        description = d.pop("description", UNSET)

        value: Union[Unset, ListResourceResponse200ItemValue] = UNSET
        _value = d.pop("value", UNSET)
        if not isinstance(_value, Unset):
            value = ListResourceResponse200ItemValue.from_dict(_value)

        extra_perms: Union[Unset, ListResourceResponse200ItemExtraPerms] = UNSET
        _extra_perms = d.pop("extra_perms", UNSET)
        if not isinstance(_extra_perms, Unset):
            extra_perms = ListResourceResponse200ItemExtraPerms.from_dict(_extra_perms)

        list_resource_response_200_item = cls(
            path=path,
            resource_type=resource_type,
            is_oauth=is_oauth,
            workspace_id=workspace_id,
            description=description,
            value=value,
            extra_perms=extra_perms,
        )

        list_resource_response_200_item.additional_properties = d
        return list_resource_response_200_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.user_workspace_list_workspaces_item import UserWorkspaceListWorkspacesItem

T = TypeVar("T", bound="UserWorkspaceList")


@attr.s(auto_attribs=True)
class UserWorkspaceList:
    """ """

    email: str
    workspaces: List[UserWorkspaceListWorkspacesItem]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        workspaces = []
        for workspaces_item_data in self.workspaces:
            workspaces_item = workspaces_item_data.to_dict()

            workspaces.append(workspaces_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "workspaces": workspaces,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        workspaces = []
        _workspaces = d.pop("workspaces")
        for workspaces_item_data in _workspaces:
            workspaces_item = UserWorkspaceListWorkspacesItem.from_dict(workspaces_item_data)

            workspaces.append(workspaces_item)

        user_workspace_list = cls(
            email=email,
            workspaces=workspaces,
        )

        user_workspace_list.additional_properties = d
        return user_workspace_list

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.list_scripts_response_200_item import ListScriptsResponse200Item
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    workspace: str,
    page: Union[Unset, int] = UNSET,
    per_page: Union[Unset, int] = UNSET,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    path_start: Union[Unset, str] = UNSET,
    path_exact: Union[Unset, str] = UNSET,
    first_parent_hash: Union[Unset, str] = UNSET,
    last_parent_hash: Union[Unset, str] = UNSET,
    parent_hash: Union[Unset, str] = UNSET,
    show_archived: Union[Unset, bool] = UNSET,
    is_template: Union[Unset, bool] = UNSET,
) -> Dict[str, Any]:
    url = "{}/w/{workspace}/scripts/list".format(client.base_url, workspace=workspace)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "page": page,
        "per_page": per_page,
        "order_desc": order_desc,
        "created_by": created_by,
        "path_start": path_start,
        "path_exact": path_exact,
        "first_parent_hash": first_parent_hash,
        "last_parent_hash": last_parent_hash,
        "parent_hash": parent_hash,
        "show_archived": show_archived,
        "is_template": is_template,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[ListScriptsResponse200Item]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = ListScriptsResponse200Item.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[ListScriptsResponse200Item]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    workspace: str,
    page: Union[Unset, int] = UNSET,
    per_page: Union[Unset, int] = UNSET,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    path_start: Union[Unset, str] = UNSET,
    path_exact: Union[Unset, str] = UNSET,
    first_parent_hash: Union[Unset, str] = UNSET,
    last_parent_hash: Union[Unset, str] = UNSET,
    parent_hash: Union[Unset, str] = UNSET,
    show_archived: Union[Unset, bool] = UNSET,
    is_template: Union[Unset, bool] = UNSET,
) -> Response[List[ListScriptsResponse200Item]]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        page=page,
        per_page=per_page,
        order_desc=order_desc,
        created_by=created_by,
        path_start=path_start,
        path_exact=path_exact,
        first_parent_hash=first_parent_hash,
        last_parent_hash=last_parent_hash,
        parent_hash=parent_hash,
        show_archived=show_archived,
        is_template=is_template,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    workspace: str,
    page: Union[Unset, int] = UNSET,
    per_page: Union[Unset, int] = UNSET,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    path_start: Union[Unset, str] = UNSET,
    path_exact: Union[Unset, str] = UNSET,
    first_parent_hash: Union[Unset, str] = UNSET,
    last_parent_hash: Union[Unset, str] = UNSET,
    parent_hash: Union[Unset, str] = UNSET,
    show_archived: Union[Unset, bool] = UNSET,
    is_template: Union[Unset, bool] = UNSET,
) -> Optional[List[ListScriptsResponse200Item]]:
    """ """

    return sync_detailed(
        client=client,
        workspace=workspace,
        page=page,
        per_page=per_page,
        order_desc=order_desc,
        created_by=created_by,
        path_start=path_start,
        path_exact=path_exact,
        first_parent_hash=first_parent_hash,
        last_parent_hash=last_parent_hash,
        parent_hash=parent_hash,
        show_archived=show_archived,
        is_template=is_template,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    workspace: str,
    page: Union[Unset, int] = UNSET,
    per_page: Union[Unset, int] = UNSET,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    path_start: Union[Unset, str] = UNSET,
    path_exact: Union[Unset, str] = UNSET,
    first_parent_hash: Union[Unset, str] = UNSET,
    last_parent_hash: Union[Unset, str] = UNSET,
    parent_hash: Union[Unset, str] = UNSET,
    show_archived: Union[Unset, bool] = UNSET,
    is_template: Union[Unset, bool] = UNSET,
) -> Response[List[ListScriptsResponse200Item]]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        page=page,
        per_page=per_page,
        order_desc=order_desc,
        created_by=created_by,
        path_start=path_start,
        path_exact=path_exact,
        first_parent_hash=first_parent_hash,
        last_parent_hash=last_parent_hash,
        parent_hash=parent_hash,
        show_archived=show_archived,
        is_template=is_template,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    workspace: str,
    page: Union[Unset, int] = UNSET,
    per_page: Union[Unset, int] = UNSET,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    path_start: Union[Unset, str] = UNSET,
    path_exact: Union[Unset, str] = UNSET,
    first_parent_hash: Union[Unset, str] = UNSET,
    last_parent_hash: Union[Unset, str] = UNSET,
    parent_hash: Union[Unset, str] = UNSET,
    show_archived: Union[Unset, bool] = UNSET,
    is_template: Union[Unset, bool] = UNSET,
) -> Optional[List[ListScriptsResponse200Item]]:
    """ """

    return (
        await asyncio_detailed(
            client=client,
            workspace=workspace,
            page=page,
            per_page=per_page,
            order_desc=order_desc,
            created_by=created_by,
            path_start=path_start,
            path_exact=path_exact,
            first_parent_hash=first_parent_hash,
            last_parent_hash=last_parent_hash,
            parent_hash=parent_hash,
            show_archived=show_archived,
            is_template=is_template,
        )
    ).parsed



from enum import Enum


class GetGranularAclsKind(str, Enum):
    SCRIPT = "script"
    GROUP = "group_"
    RESOURCE = "resource"
    SCHEDULE = "schedule"
    VARIABLE = "variable"
    FLOW = "flow"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.connect_slack_callback_response_200_bot import ConnectSlackCallbackResponse200Bot

T = TypeVar("T", bound="ConnectSlackCallbackResponse200")


@attr.s(auto_attribs=True)
class ConnectSlackCallbackResponse200:
    """ """

    access_token: str
    team_id: str
    team_name: str
    bot: ConnectSlackCallbackResponse200Bot
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        access_token = self.access_token
        team_id = self.team_id
        team_name = self.team_name
        bot = self.bot.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "access_token": access_token,
                "team_id": team_id,
                "team_name": team_name,
                "bot": bot,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        access_token = d.pop("access_token")

        team_id = d.pop("team_id")

        team_name = d.pop("team_name")

        bot = ConnectSlackCallbackResponse200Bot.from_dict(d.pop("bot"))

        connect_slack_callback_response_200 = cls(
            access_token=access_token,
            team_id=team_id,
            team_name=team_name,
            bot=bot,
        )

        connect_slack_callback_response_200.additional_properties = d
        return connect_slack_callback_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.flow_preview_value_failure_module import FlowPreviewValueFailureModule
from ..models.flow_preview_value_modules_item import FlowPreviewValueModulesItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="FlowPreviewValue")


@attr.s(auto_attribs=True)
class FlowPreviewValue:
    """ """

    modules: List[FlowPreviewValueModulesItem]
    failure_module: Union[Unset, FlowPreviewValueFailureModule] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        modules = []
        for modules_item_data in self.modules:
            modules_item = modules_item_data.to_dict()

            modules.append(modules_item)

        failure_module: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.failure_module, Unset):
            failure_module = self.failure_module.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "modules": modules,
            }
        )
        if failure_module is not UNSET:
            field_dict["failure_module"] = failure_module

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        modules = []
        _modules = d.pop("modules")
        for modules_item_data in _modules:
            modules_item = FlowPreviewValueModulesItem.from_dict(modules_item_data)

            modules.append(modules_item)

        failure_module: Union[Unset, FlowPreviewValueFailureModule] = UNSET
        _failure_module = d.pop("failure_module", UNSET)
        if not isinstance(_failure_module, Unset):
            failure_module = FlowPreviewValueFailureModule.from_dict(_failure_module)

        flow_preview_value = cls(
            modules=modules,
            failure_module=failure_module,
        )

        flow_preview_value.additional_properties = d
        return flow_preview_value

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="EditVariable")


@attr.s(auto_attribs=True)
class EditVariable:
    """ """

    path: Union[Unset, str] = UNSET
    value: Union[Unset, str] = UNSET
    is_secret: Union[Unset, bool] = UNSET
    description: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        value = self.value
        is_secret = self.is_secret
        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if path is not UNSET:
            field_dict["path"] = path
        if value is not UNSET:
            field_dict["value"] = value
        if is_secret is not UNSET:
            field_dict["is_secret"] = is_secret
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path", UNSET)

        value = d.pop("value", UNSET)

        is_secret = d.pop("is_secret", UNSET)

        description = d.pop("description", UNSET)

        edit_variable = cls(
            path=path,
            value=value,
            is_secret=is_secret,
            description=description,
        )

        edit_variable.additional_properties = d
        return edit_variable

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="CreateWorkspaceJsonBody")


@attr.s(auto_attribs=True)
class CreateWorkspaceJsonBody:
    """ """

    id: str
    name: str
    username: str
    domain: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        name = self.name
        username = self.username
        domain = self.domain

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "name": name,
                "username": username,
                "domain": domain,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        name = d.pop("name")

        username = d.pop("username")

        domain = d.pop("domain")

        create_workspace_json_body = cls(
            id=id,
            name=name,
            username=username,
            domain=domain,
        )

        create_workspace_json_body.additional_properties = d
        return create_workspace_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .accept_invite_json_body import AcceptInviteJsonBody
from .add_granular_acls_json_body import AddGranularAclsJsonBody
from .add_granular_acls_kind import AddGranularAclsKind
from .add_user_to_group_json_body import AddUserToGroupJsonBody
from .archive_script_by_hash_response_200 import ArchiveScriptByHashResponse200
from .archive_script_by_hash_response_200_extra_perms import ArchiveScriptByHashResponse200ExtraPerms
from .archive_script_by_hash_response_200_language import ArchiveScriptByHashResponse200Language
from .archive_script_by_hash_response_200_schema import ArchiveScriptByHashResponse200Schema
from .audit_log import AuditLog
from .audit_log_action_kind import AuditLogActionKind
from .audit_log_operation import AuditLogOperation
from .audit_log_parameters import AuditLogParameters
from .cancel_queued_job_json_body import CancelQueuedJobJsonBody
from .completed_job import CompletedJob
from .completed_job_args import CompletedJobArgs
from .completed_job_flow_status import CompletedJobFlowStatus
from .completed_job_flow_status_failure_module import CompletedJobFlowStatusFailureModule
from .completed_job_flow_status_failure_module_type import CompletedJobFlowStatusFailureModuleType
from .completed_job_flow_status_modules_item import CompletedJobFlowStatusModulesItem
from .completed_job_flow_status_modules_item_type import CompletedJobFlowStatusModulesItemType
from .completed_job_job_kind import CompletedJobJobKind
from .completed_job_language import CompletedJobLanguage
from .completed_job_raw_flow import CompletedJobRawFlow
from .completed_job_raw_flow_failure_module import CompletedJobRawFlowFailureModule
from .completed_job_raw_flow_failure_module_input_transform import CompletedJobRawFlowFailureModuleInputTransform
from .completed_job_raw_flow_failure_module_input_transform_additional_property import (
    CompletedJobRawFlowFailureModuleInputTransformAdditionalProperty,
)
from .completed_job_raw_flow_failure_module_input_transform_additional_property_type import (
    CompletedJobRawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from .completed_job_raw_flow_failure_module_value import CompletedJobRawFlowFailureModuleValue
from .completed_job_raw_flow_failure_module_value_language import CompletedJobRawFlowFailureModuleValueLanguage
from .completed_job_raw_flow_failure_module_value_type import CompletedJobRawFlowFailureModuleValueType
from .completed_job_raw_flow_modules_item import CompletedJobRawFlowModulesItem
from .completed_job_raw_flow_modules_item_input_transform import CompletedJobRawFlowModulesItemInputTransform
from .completed_job_raw_flow_modules_item_input_transform_additional_property import (
    CompletedJobRawFlowModulesItemInputTransformAdditionalProperty,
)
from .completed_job_raw_flow_modules_item_input_transform_additional_property_type import (
    CompletedJobRawFlowModulesItemInputTransformAdditionalPropertyType,
)
from .completed_job_raw_flow_modules_item_value import CompletedJobRawFlowModulesItemValue
from .completed_job_raw_flow_modules_item_value_language import CompletedJobRawFlowModulesItemValueLanguage
from .completed_job_raw_flow_modules_item_value_type import CompletedJobRawFlowModulesItemValueType
from .completed_job_result import CompletedJobResult
from .connect_callback_json_body import ConnectCallbackJsonBody
from .connect_callback_response_200 import ConnectCallbackResponse200
from .connect_slack_callback_json_body import ConnectSlackCallbackJsonBody
from .connect_slack_callback_response_200 import ConnectSlackCallbackResponse200
from .connect_slack_callback_response_200_bot import ConnectSlackCallbackResponse200Bot
from .contextual_variable import ContextualVariable
from .create_account_json_body import CreateAccountJsonBody
from .create_flow_json_body import CreateFlowJsonBody
from .create_flow_json_body_schema import CreateFlowJsonBodySchema
from .create_flow_json_body_value import CreateFlowJsonBodyValue
from .create_flow_json_body_value_failure_module import CreateFlowJsonBodyValueFailureModule
from .create_flow_json_body_value_failure_module_input_transform import (
    CreateFlowJsonBodyValueFailureModuleInputTransform,
)
from .create_flow_json_body_value_failure_module_input_transform_additional_property import (
    CreateFlowJsonBodyValueFailureModuleInputTransformAdditionalProperty,
)
from .create_flow_json_body_value_failure_module_input_transform_additional_property_type import (
    CreateFlowJsonBodyValueFailureModuleInputTransformAdditionalPropertyType,
)
from .create_flow_json_body_value_failure_module_value import CreateFlowJsonBodyValueFailureModuleValue
from .create_flow_json_body_value_failure_module_value_language import CreateFlowJsonBodyValueFailureModuleValueLanguage
from .create_flow_json_body_value_failure_module_value_type import CreateFlowJsonBodyValueFailureModuleValueType
from .create_flow_json_body_value_modules_item import CreateFlowJsonBodyValueModulesItem
from .create_flow_json_body_value_modules_item_input_transform import CreateFlowJsonBodyValueModulesItemInputTransform
from .create_flow_json_body_value_modules_item_input_transform_additional_property import (
    CreateFlowJsonBodyValueModulesItemInputTransformAdditionalProperty,
)
from .create_flow_json_body_value_modules_item_input_transform_additional_property_type import (
    CreateFlowJsonBodyValueModulesItemInputTransformAdditionalPropertyType,
)
from .create_flow_json_body_value_modules_item_value import CreateFlowJsonBodyValueModulesItemValue
from .create_flow_json_body_value_modules_item_value_language import CreateFlowJsonBodyValueModulesItemValueLanguage
from .create_flow_json_body_value_modules_item_value_type import CreateFlowJsonBodyValueModulesItemValueType
from .create_group_json_body import CreateGroupJsonBody
from .create_resource import CreateResource
from .create_resource_json_body import CreateResourceJsonBody
from .create_resource_json_body_value import CreateResourceJsonBodyValue
from .create_resource_type_json_body import CreateResourceTypeJsonBody
from .create_resource_value import CreateResourceValue
from .create_schedule_json_body import CreateScheduleJsonBody
from .create_schedule_json_body_args import CreateScheduleJsonBodyArgs
from .create_script_json_body import CreateScriptJsonBody
from .create_script_json_body_language import CreateScriptJsonBodyLanguage
from .create_script_json_body_schema import CreateScriptJsonBodySchema
from .create_token_json_body import CreateTokenJsonBody
from .create_user_globally_json_body import CreateUserGloballyJsonBody
from .create_user_json_body import CreateUserJsonBody
from .create_variable import CreateVariable
from .create_variable_json_body import CreateVariableJsonBody
from .create_workspace import CreateWorkspace
from .create_workspace_json_body import CreateWorkspaceJsonBody
from .decline_invite_json_body import DeclineInviteJsonBody
from .delete_completed_job_response_200 import DeleteCompletedJobResponse200
from .delete_completed_job_response_200_args import DeleteCompletedJobResponse200Args
from .delete_completed_job_response_200_flow_status import DeleteCompletedJobResponse200FlowStatus
from .delete_completed_job_response_200_flow_status_failure_module import (
    DeleteCompletedJobResponse200FlowStatusFailureModule,
)
from .delete_completed_job_response_200_flow_status_failure_module_type import (
    DeleteCompletedJobResponse200FlowStatusFailureModuleType,
)
from .delete_completed_job_response_200_flow_status_modules_item import (
    DeleteCompletedJobResponse200FlowStatusModulesItem,
)
from .delete_completed_job_response_200_flow_status_modules_item_type import (
    DeleteCompletedJobResponse200FlowStatusModulesItemType,
)
from .delete_completed_job_response_200_job_kind import DeleteCompletedJobResponse200JobKind
from .delete_completed_job_response_200_language import DeleteCompletedJobResponse200Language
from .delete_completed_job_response_200_raw_flow import DeleteCompletedJobResponse200RawFlow
from .delete_completed_job_response_200_raw_flow_failure_module import DeleteCompletedJobResponse200RawFlowFailureModule
from .delete_completed_job_response_200_raw_flow_failure_module_input_transform import (
    DeleteCompletedJobResponse200RawFlowFailureModuleInputTransform,
)
from .delete_completed_job_response_200_raw_flow_failure_module_input_transform_additional_property import (
    DeleteCompletedJobResponse200RawFlowFailureModuleInputTransformAdditionalProperty,
)
from .delete_completed_job_response_200_raw_flow_failure_module_input_transform_additional_property_type import (
    DeleteCompletedJobResponse200RawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from .delete_completed_job_response_200_raw_flow_failure_module_value import (
    DeleteCompletedJobResponse200RawFlowFailureModuleValue,
)
from .delete_completed_job_response_200_raw_flow_failure_module_value_language import (
    DeleteCompletedJobResponse200RawFlowFailureModuleValueLanguage,
)
from .delete_completed_job_response_200_raw_flow_failure_module_value_type import (
    DeleteCompletedJobResponse200RawFlowFailureModuleValueType,
)
from .delete_completed_job_response_200_raw_flow_modules_item import DeleteCompletedJobResponse200RawFlowModulesItem
from .delete_completed_job_response_200_raw_flow_modules_item_input_transform import (
    DeleteCompletedJobResponse200RawFlowModulesItemInputTransform,
)
from .delete_completed_job_response_200_raw_flow_modules_item_input_transform_additional_property import (
    DeleteCompletedJobResponse200RawFlowModulesItemInputTransformAdditionalProperty,
)
from .delete_completed_job_response_200_raw_flow_modules_item_input_transform_additional_property_type import (
    DeleteCompletedJobResponse200RawFlowModulesItemInputTransformAdditionalPropertyType,
)
from .delete_completed_job_response_200_raw_flow_modules_item_value import (
    DeleteCompletedJobResponse200RawFlowModulesItemValue,
)
from .delete_completed_job_response_200_raw_flow_modules_item_value_language import (
    DeleteCompletedJobResponse200RawFlowModulesItemValueLanguage,
)
from .delete_completed_job_response_200_raw_flow_modules_item_value_type import (
    DeleteCompletedJobResponse200RawFlowModulesItemValueType,
)
from .delete_completed_job_response_200_result import DeleteCompletedJobResponse200Result
from .delete_invite_json_body import DeleteInviteJsonBody
from .delete_script_by_hash_response_200 import DeleteScriptByHashResponse200
from .delete_script_by_hash_response_200_extra_perms import DeleteScriptByHashResponse200ExtraPerms
from .delete_script_by_hash_response_200_language import DeleteScriptByHashResponse200Language
from .delete_script_by_hash_response_200_schema import DeleteScriptByHashResponse200Schema
from .deno_to_jsonschema_response_200 import DenoToJsonschemaResponse200
from .deno_to_jsonschema_response_200_args_item import DenoToJsonschemaResponse200ArgsItem
from .deno_to_jsonschema_response_200_args_item_typ_type_0 import DenoToJsonschemaResponse200ArgsItemTypType0
from .deno_to_jsonschema_response_200_args_item_typ_type_1 import DenoToJsonschemaResponse200ArgsItemTypType1
from .deno_to_jsonschema_response_200_args_item_typ_type_2 import DenoToJsonschemaResponse200ArgsItemTypType2
from .deno_to_jsonschema_response_200_args_item_typ_type_2_list import DenoToJsonschemaResponse200ArgsItemTypType2List
from .edit_resource import EditResource
from .edit_resource_type import EditResourceType
from .edit_resource_value import EditResourceValue
from .edit_schedule import EditSchedule
from .edit_schedule_args import EditScheduleArgs
from .edit_slack_command_json_body import EditSlackCommandJsonBody
from .edit_variable import EditVariable
from .edit_workspace_user import EditWorkspaceUser
from .flow import Flow
from .flow_extra_perms import FlowExtraPerms
from .flow_module import FlowModule
from .flow_module_input_transform import FlowModuleInputTransform
from .flow_module_input_transform_additional_property import FlowModuleInputTransformAdditionalProperty
from .flow_module_input_transform_additional_property_type import FlowModuleInputTransformAdditionalPropertyType
from .flow_module_value import FlowModuleValue
from .flow_module_value_language import FlowModuleValueLanguage
from .flow_module_value_type import FlowModuleValueType
from .flow_preview import FlowPreview
from .flow_preview_args import FlowPreviewArgs
from .flow_preview_value import FlowPreviewValue
from .flow_preview_value_failure_module import FlowPreviewValueFailureModule
from .flow_preview_value_failure_module_input_transform import FlowPreviewValueFailureModuleInputTransform
from .flow_preview_value_failure_module_input_transform_additional_property import (
    FlowPreviewValueFailureModuleInputTransformAdditionalProperty,
)
from .flow_preview_value_failure_module_input_transform_additional_property_type import (
    FlowPreviewValueFailureModuleInputTransformAdditionalPropertyType,
)
from .flow_preview_value_failure_module_value import FlowPreviewValueFailureModuleValue
from .flow_preview_value_failure_module_value_language import FlowPreviewValueFailureModuleValueLanguage
from .flow_preview_value_failure_module_value_type import FlowPreviewValueFailureModuleValueType
from .flow_preview_value_modules_item import FlowPreviewValueModulesItem
from .flow_preview_value_modules_item_input_transform import FlowPreviewValueModulesItemInputTransform
from .flow_preview_value_modules_item_input_transform_additional_property import (
    FlowPreviewValueModulesItemInputTransformAdditionalProperty,
)
from .flow_preview_value_modules_item_input_transform_additional_property_type import (
    FlowPreviewValueModulesItemInputTransformAdditionalPropertyType,
)
from .flow_preview_value_modules_item_value import FlowPreviewValueModulesItemValue
from .flow_preview_value_modules_item_value_language import FlowPreviewValueModulesItemValueLanguage
from .flow_preview_value_modules_item_value_type import FlowPreviewValueModulesItemValueType
from .flow_schema import FlowSchema
from .flow_status import FlowStatus
from .flow_status_failure_module import FlowStatusFailureModule
from .flow_status_failure_module_type import FlowStatusFailureModuleType
from .flow_status_module import FlowStatusModule
from .flow_status_module_type import FlowStatusModuleType
from .flow_status_modules_item import FlowStatusModulesItem
from .flow_status_modules_item_type import FlowStatusModulesItemType
from .flow_value import FlowValue
from .flow_value_failure_module import FlowValueFailureModule
from .flow_value_failure_module_input_transform import FlowValueFailureModuleInputTransform
from .flow_value_failure_module_input_transform_additional_property import (
    FlowValueFailureModuleInputTransformAdditionalProperty,
)
from .flow_value_failure_module_input_transform_additional_property_type import (
    FlowValueFailureModuleInputTransformAdditionalPropertyType,
)
from .flow_value_failure_module_value import FlowValueFailureModuleValue
from .flow_value_failure_module_value_language import FlowValueFailureModuleValueLanguage
from .flow_value_failure_module_value_type import FlowValueFailureModuleValueType
from .flow_value_modules_item import FlowValueModulesItem
from .flow_value_modules_item_input_transform import FlowValueModulesItemInputTransform
from .flow_value_modules_item_input_transform_additional_property import (
    FlowValueModulesItemInputTransformAdditionalProperty,
)
from .flow_value_modules_item_input_transform_additional_property_type import (
    FlowValueModulesItemInputTransformAdditionalPropertyType,
)
from .flow_value_modules_item_value import FlowValueModulesItemValue
from .flow_value_modules_item_value_language import FlowValueModulesItemValueLanguage
from .flow_value_modules_item_value_type import FlowValueModulesItemValueType
from .get_audit_log_response_200 import GetAuditLogResponse200
from .get_audit_log_response_200_action_kind import GetAuditLogResponse200ActionKind
from .get_audit_log_response_200_operation import GetAuditLogResponse200Operation
from .get_audit_log_response_200_parameters import GetAuditLogResponse200Parameters
from .get_completed_job_response_200 import GetCompletedJobResponse200
from .get_completed_job_response_200_args import GetCompletedJobResponse200Args
from .get_completed_job_response_200_flow_status import GetCompletedJobResponse200FlowStatus
from .get_completed_job_response_200_flow_status_failure_module import GetCompletedJobResponse200FlowStatusFailureModule
from .get_completed_job_response_200_flow_status_failure_module_type import (
    GetCompletedJobResponse200FlowStatusFailureModuleType,
)
from .get_completed_job_response_200_flow_status_modules_item import GetCompletedJobResponse200FlowStatusModulesItem
from .get_completed_job_response_200_flow_status_modules_item_type import (
    GetCompletedJobResponse200FlowStatusModulesItemType,
)
from .get_completed_job_response_200_job_kind import GetCompletedJobResponse200JobKind
from .get_completed_job_response_200_language import GetCompletedJobResponse200Language
from .get_completed_job_response_200_raw_flow import GetCompletedJobResponse200RawFlow
from .get_completed_job_response_200_raw_flow_failure_module import GetCompletedJobResponse200RawFlowFailureModule
from .get_completed_job_response_200_raw_flow_failure_module_input_transform import (
    GetCompletedJobResponse200RawFlowFailureModuleInputTransform,
)
from .get_completed_job_response_200_raw_flow_failure_module_input_transform_additional_property import (
    GetCompletedJobResponse200RawFlowFailureModuleInputTransformAdditionalProperty,
)
from .get_completed_job_response_200_raw_flow_failure_module_input_transform_additional_property_type import (
    GetCompletedJobResponse200RawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from .get_completed_job_response_200_raw_flow_failure_module_value import (
    GetCompletedJobResponse200RawFlowFailureModuleValue,
)
from .get_completed_job_response_200_raw_flow_failure_module_value_language import (
    GetCompletedJobResponse200RawFlowFailureModuleValueLanguage,
)
from .get_completed_job_response_200_raw_flow_failure_module_value_type import (
    GetCompletedJobResponse200RawFlowFailureModuleValueType,
)
from .get_completed_job_response_200_raw_flow_modules_item import GetCompletedJobResponse200RawFlowModulesItem
from .get_completed_job_response_200_raw_flow_modules_item_input_transform import (
    GetCompletedJobResponse200RawFlowModulesItemInputTransform,
)
from .get_completed_job_response_200_raw_flow_modules_item_input_transform_additional_property import (
    GetCompletedJobResponse200RawFlowModulesItemInputTransformAdditionalProperty,
)
from .get_completed_job_response_200_raw_flow_modules_item_input_transform_additional_property_type import (
    GetCompletedJobResponse200RawFlowModulesItemInputTransformAdditionalPropertyType,
)
from .get_completed_job_response_200_raw_flow_modules_item_value import (
    GetCompletedJobResponse200RawFlowModulesItemValue,
)
from .get_completed_job_response_200_raw_flow_modules_item_value_language import (
    GetCompletedJobResponse200RawFlowModulesItemValueLanguage,
)
from .get_completed_job_response_200_raw_flow_modules_item_value_type import (
    GetCompletedJobResponse200RawFlowModulesItemValueType,
)
from .get_completed_job_response_200_result import GetCompletedJobResponse200Result
from .get_flow_by_path_response_200 import GetFlowByPathResponse200
from .get_flow_by_path_response_200_extra_perms import GetFlowByPathResponse200ExtraPerms
from .get_flow_by_path_response_200_schema import GetFlowByPathResponse200Schema
from .get_flow_by_path_response_200_value import GetFlowByPathResponse200Value
from .get_flow_by_path_response_200_value_failure_module import GetFlowByPathResponse200ValueFailureModule
from .get_flow_by_path_response_200_value_failure_module_input_transform import (
    GetFlowByPathResponse200ValueFailureModuleInputTransform,
)
from .get_flow_by_path_response_200_value_failure_module_input_transform_additional_property import (
    GetFlowByPathResponse200ValueFailureModuleInputTransformAdditionalProperty,
)
from .get_flow_by_path_response_200_value_failure_module_input_transform_additional_property_type import (
    GetFlowByPathResponse200ValueFailureModuleInputTransformAdditionalPropertyType,
)
from .get_flow_by_path_response_200_value_failure_module_value import GetFlowByPathResponse200ValueFailureModuleValue
from .get_flow_by_path_response_200_value_failure_module_value_language import (
    GetFlowByPathResponse200ValueFailureModuleValueLanguage,
)
from .get_flow_by_path_response_200_value_failure_module_value_type import (
    GetFlowByPathResponse200ValueFailureModuleValueType,
)
from .get_flow_by_path_response_200_value_modules_item import GetFlowByPathResponse200ValueModulesItem
from .get_flow_by_path_response_200_value_modules_item_input_transform import (
    GetFlowByPathResponse200ValueModulesItemInputTransform,
)
from .get_flow_by_path_response_200_value_modules_item_input_transform_additional_property import (
    GetFlowByPathResponse200ValueModulesItemInputTransformAdditionalProperty,
)
from .get_flow_by_path_response_200_value_modules_item_input_transform_additional_property_type import (
    GetFlowByPathResponse200ValueModulesItemInputTransformAdditionalPropertyType,
)
from .get_flow_by_path_response_200_value_modules_item_value import GetFlowByPathResponse200ValueModulesItemValue
from .get_flow_by_path_response_200_value_modules_item_value_language import (
    GetFlowByPathResponse200ValueModulesItemValueLanguage,
)
from .get_flow_by_path_response_200_value_modules_item_value_type import (
    GetFlowByPathResponse200ValueModulesItemValueType,
)
from .get_granular_acls_kind import GetGranularAclsKind
from .get_granular_acls_response_200 import GetGranularAclsResponse200
from .get_group_response_200 import GetGroupResponse200
from .get_group_response_200_extra_perms import GetGroupResponse200ExtraPerms
from .get_job_response_200 import GetJobResponse200
from .get_job_response_200_type import GetJobResponse200Type
from .get_job_updates_response_200 import GetJobUpdatesResponse200
from .get_resource_response_200 import GetResourceResponse200
from .get_resource_response_200_extra_perms import GetResourceResponse200ExtraPerms
from .get_resource_response_200_value import GetResourceResponse200Value
from .get_resource_type_response_200 import GetResourceTypeResponse200
from .get_schedule_response_200 import GetScheduleResponse200
from .get_schedule_response_200_args import GetScheduleResponse200Args
from .get_schedule_response_200_extra_perms import GetScheduleResponse200ExtraPerms
from .get_script_by_hash_response_200 import GetScriptByHashResponse200
from .get_script_by_hash_response_200_extra_perms import GetScriptByHashResponse200ExtraPerms
from .get_script_by_hash_response_200_language import GetScriptByHashResponse200Language
from .get_script_by_hash_response_200_schema import GetScriptByHashResponse200Schema
from .get_script_by_path_response_200 import GetScriptByPathResponse200
from .get_script_by_path_response_200_extra_perms import GetScriptByPathResponse200ExtraPerms
from .get_script_by_path_response_200_language import GetScriptByPathResponse200Language
from .get_script_by_path_response_200_schema import GetScriptByPathResponse200Schema
from .get_script_deployment_status_response_200 import GetScriptDeploymentStatusResponse200
from .get_settings_response_200 import GetSettingsResponse200
from .get_variable_response_200 import GetVariableResponse200
from .get_variable_response_200_extra_perms import GetVariableResponse200ExtraPerms
from .global_user_info import GlobalUserInfo
from .global_user_info_login_type import GlobalUserInfoLoginType
from .global_user_update_json_body import GlobalUserUpdateJsonBody
from .global_whoami_response_200 import GlobalWhoamiResponse200
from .global_whoami_response_200_login_type import GlobalWhoamiResponse200LoginType
from .group import Group
from .group_extra_perms import GroupExtraPerms
from .input_transform import InputTransform
from .input_transform_type import InputTransformType
from .invite_user_json_body import InviteUserJsonBody
from .job import Job
from .job_type import JobType
from .list_audit_logs_action_kind import ListAuditLogsActionKind
from .list_audit_logs_response_200_item import ListAuditLogsResponse200Item
from .list_audit_logs_response_200_item_action_kind import ListAuditLogsResponse200ItemActionKind
from .list_audit_logs_response_200_item_operation import ListAuditLogsResponse200ItemOperation
from .list_audit_logs_response_200_item_parameters import ListAuditLogsResponse200ItemParameters
from .list_completed_jobs_response_200_item import ListCompletedJobsResponse200Item
from .list_completed_jobs_response_200_item_args import ListCompletedJobsResponse200ItemArgs
from .list_completed_jobs_response_200_item_flow_status import ListCompletedJobsResponse200ItemFlowStatus
from .list_completed_jobs_response_200_item_flow_status_failure_module import (
    ListCompletedJobsResponse200ItemFlowStatusFailureModule,
)
from .list_completed_jobs_response_200_item_flow_status_failure_module_type import (
    ListCompletedJobsResponse200ItemFlowStatusFailureModuleType,
)
from .list_completed_jobs_response_200_item_flow_status_modules_item import (
    ListCompletedJobsResponse200ItemFlowStatusModulesItem,
)
from .list_completed_jobs_response_200_item_flow_status_modules_item_type import (
    ListCompletedJobsResponse200ItemFlowStatusModulesItemType,
)
from .list_completed_jobs_response_200_item_job_kind import ListCompletedJobsResponse200ItemJobKind
from .list_completed_jobs_response_200_item_language import ListCompletedJobsResponse200ItemLanguage
from .list_completed_jobs_response_200_item_raw_flow import ListCompletedJobsResponse200ItemRawFlow
from .list_completed_jobs_response_200_item_raw_flow_failure_module import (
    ListCompletedJobsResponse200ItemRawFlowFailureModule,
)
from .list_completed_jobs_response_200_item_raw_flow_failure_module_input_transform import (
    ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransform,
)
from .list_completed_jobs_response_200_item_raw_flow_failure_module_input_transform_additional_property import (
    ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransformAdditionalProperty,
)
from .list_completed_jobs_response_200_item_raw_flow_failure_module_input_transform_additional_property_type import (
    ListCompletedJobsResponse200ItemRawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from .list_completed_jobs_response_200_item_raw_flow_failure_module_value import (
    ListCompletedJobsResponse200ItemRawFlowFailureModuleValue,
)
from .list_completed_jobs_response_200_item_raw_flow_failure_module_value_language import (
    ListCompletedJobsResponse200ItemRawFlowFailureModuleValueLanguage,
)
from .list_completed_jobs_response_200_item_raw_flow_failure_module_value_type import (
    ListCompletedJobsResponse200ItemRawFlowFailureModuleValueType,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item import (
    ListCompletedJobsResponse200ItemRawFlowModulesItem,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item_input_transform import (
    ListCompletedJobsResponse200ItemRawFlowModulesItemInputTransform,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item_input_transform_additional_property import (
    ListCompletedJobsResponse200ItemRawFlowModulesItemInputTransformAdditionalProperty,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item_input_transform_additional_property_type import (
    ListCompletedJobsResponse200ItemRawFlowModulesItemInputTransformAdditionalPropertyType,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item_value import (
    ListCompletedJobsResponse200ItemRawFlowModulesItemValue,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item_value_language import (
    ListCompletedJobsResponse200ItemRawFlowModulesItemValueLanguage,
)
from .list_completed_jobs_response_200_item_raw_flow_modules_item_value_type import (
    ListCompletedJobsResponse200ItemRawFlowModulesItemValueType,
)
from .list_completed_jobs_response_200_item_result import ListCompletedJobsResponse200ItemResult
from .list_contextual_variables_response_200_item import ListContextualVariablesResponse200Item
from .list_flows_response_200_item import ListFlowsResponse200Item
from .list_flows_response_200_item_extra_perms import ListFlowsResponse200ItemExtraPerms
from .list_flows_response_200_item_schema import ListFlowsResponse200ItemSchema
from .list_flows_response_200_item_value import ListFlowsResponse200ItemValue
from .list_flows_response_200_item_value_failure_module import ListFlowsResponse200ItemValueFailureModule
from .list_flows_response_200_item_value_failure_module_input_transform import (
    ListFlowsResponse200ItemValueFailureModuleInputTransform,
)
from .list_flows_response_200_item_value_failure_module_input_transform_additional_property import (
    ListFlowsResponse200ItemValueFailureModuleInputTransformAdditionalProperty,
)
from .list_flows_response_200_item_value_failure_module_input_transform_additional_property_type import (
    ListFlowsResponse200ItemValueFailureModuleInputTransformAdditionalPropertyType,
)
from .list_flows_response_200_item_value_failure_module_value import ListFlowsResponse200ItemValueFailureModuleValue
from .list_flows_response_200_item_value_failure_module_value_language import (
    ListFlowsResponse200ItemValueFailureModuleValueLanguage,
)
from .list_flows_response_200_item_value_failure_module_value_type import (
    ListFlowsResponse200ItemValueFailureModuleValueType,
)
from .list_flows_response_200_item_value_modules_item import ListFlowsResponse200ItemValueModulesItem
from .list_flows_response_200_item_value_modules_item_input_transform import (
    ListFlowsResponse200ItemValueModulesItemInputTransform,
)
from .list_flows_response_200_item_value_modules_item_input_transform_additional_property import (
    ListFlowsResponse200ItemValueModulesItemInputTransformAdditionalProperty,
)
from .list_flows_response_200_item_value_modules_item_input_transform_additional_property_type import (
    ListFlowsResponse200ItemValueModulesItemInputTransformAdditionalPropertyType,
)
from .list_flows_response_200_item_value_modules_item_value import ListFlowsResponse200ItemValueModulesItemValue
from .list_flows_response_200_item_value_modules_item_value_language import (
    ListFlowsResponse200ItemValueModulesItemValueLanguage,
)
from .list_flows_response_200_item_value_modules_item_value_type import (
    ListFlowsResponse200ItemValueModulesItemValueType,
)
from .list_groups_response_200_item import ListGroupsResponse200Item
from .list_groups_response_200_item_extra_perms import ListGroupsResponse200ItemExtraPerms
from .list_hub_scripts_response_200_item import ListHubScriptsResponse200Item
from .list_jobs_response_200_item import ListJobsResponse200Item
from .list_jobs_response_200_item_type import ListJobsResponse200ItemType
from .list_pending_invites_response_200_item import ListPendingInvitesResponse200Item
from .list_queue_response_200_item import ListQueueResponse200Item
from .list_queue_response_200_item_args import ListQueueResponse200ItemArgs
from .list_queue_response_200_item_flow_status import ListQueueResponse200ItemFlowStatus
from .list_queue_response_200_item_flow_status_failure_module import ListQueueResponse200ItemFlowStatusFailureModule
from .list_queue_response_200_item_flow_status_failure_module_type import (
    ListQueueResponse200ItemFlowStatusFailureModuleType,
)
from .list_queue_response_200_item_flow_status_modules_item import ListQueueResponse200ItemFlowStatusModulesItem
from .list_queue_response_200_item_flow_status_modules_item_type import (
    ListQueueResponse200ItemFlowStatusModulesItemType,
)
from .list_queue_response_200_item_job_kind import ListQueueResponse200ItemJobKind
from .list_queue_response_200_item_language import ListQueueResponse200ItemLanguage
from .list_queue_response_200_item_raw_flow import ListQueueResponse200ItemRawFlow
from .list_queue_response_200_item_raw_flow_failure_module import ListQueueResponse200ItemRawFlowFailureModule
from .list_queue_response_200_item_raw_flow_failure_module_input_transform import (
    ListQueueResponse200ItemRawFlowFailureModuleInputTransform,
)
from .list_queue_response_200_item_raw_flow_failure_module_input_transform_additional_property import (
    ListQueueResponse200ItemRawFlowFailureModuleInputTransformAdditionalProperty,
)
from .list_queue_response_200_item_raw_flow_failure_module_input_transform_additional_property_type import (
    ListQueueResponse200ItemRawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from .list_queue_response_200_item_raw_flow_failure_module_value import (
    ListQueueResponse200ItemRawFlowFailureModuleValue,
)
from .list_queue_response_200_item_raw_flow_failure_module_value_language import (
    ListQueueResponse200ItemRawFlowFailureModuleValueLanguage,
)
from .list_queue_response_200_item_raw_flow_failure_module_value_type import (
    ListQueueResponse200ItemRawFlowFailureModuleValueType,
)
from .list_queue_response_200_item_raw_flow_modules_item import ListQueueResponse200ItemRawFlowModulesItem
from .list_queue_response_200_item_raw_flow_modules_item_input_transform import (
    ListQueueResponse200ItemRawFlowModulesItemInputTransform,
)
from .list_queue_response_200_item_raw_flow_modules_item_input_transform_additional_property import (
    ListQueueResponse200ItemRawFlowModulesItemInputTransformAdditionalProperty,
)
from .list_queue_response_200_item_raw_flow_modules_item_input_transform_additional_property_type import (
    ListQueueResponse200ItemRawFlowModulesItemInputTransformAdditionalPropertyType,
)
from .list_queue_response_200_item_raw_flow_modules_item_value import ListQueueResponse200ItemRawFlowModulesItemValue
from .list_queue_response_200_item_raw_flow_modules_item_value_language import (
    ListQueueResponse200ItemRawFlowModulesItemValueLanguage,
)
from .list_queue_response_200_item_raw_flow_modules_item_value_type import (
    ListQueueResponse200ItemRawFlowModulesItemValueType,
)
from .list_resource_response_200_item import ListResourceResponse200Item
from .list_resource_response_200_item_extra_perms import ListResourceResponse200ItemExtraPerms
from .list_resource_response_200_item_value import ListResourceResponse200ItemValue
from .list_resource_type_response_200_item import ListResourceTypeResponse200Item
from .list_schedules_response_200_item import ListSchedulesResponse200Item
from .list_schedules_response_200_item_args import ListSchedulesResponse200ItemArgs
from .list_schedules_response_200_item_extra_perms import ListSchedulesResponse200ItemExtraPerms
from .list_scripts_response_200_item import ListScriptsResponse200Item
from .list_scripts_response_200_item_extra_perms import ListScriptsResponse200ItemExtraPerms
from .list_scripts_response_200_item_language import ListScriptsResponse200ItemLanguage
from .list_scripts_response_200_item_schema import ListScriptsResponse200ItemSchema
from .list_tokens_response_200_item import ListTokensResponse200Item
from .list_user_workspaces_response_200 import ListUserWorkspacesResponse200
from .list_user_workspaces_response_200_workspaces_item import ListUserWorkspacesResponse200WorkspacesItem
from .list_users_as_super_admin_response_200_item import ListUsersAsSuperAdminResponse200Item
from .list_users_as_super_admin_response_200_item_login_type import ListUsersAsSuperAdminResponse200ItemLoginType
from .list_users_response_200_item import ListUsersResponse200Item
from .list_variable_response_200_item import ListVariableResponse200Item
from .list_variable_response_200_item_extra_perms import ListVariableResponse200ItemExtraPerms
from .list_workers_response_200_item import ListWorkersResponse200Item
from .list_workspace_invites_response_200_item import ListWorkspaceInvitesResponse200Item
from .list_workspaces_as_super_admin_response_200_item import ListWorkspacesAsSuperAdminResponse200Item
from .list_workspaces_response_200_item import ListWorkspacesResponse200Item
from .listable_variable import ListableVariable
from .listable_variable_extra_perms import ListableVariableExtraPerms
from .login import Login
from .login_json_body import LoginJsonBody
from .login_with_oauth_json_body import LoginWithOauthJsonBody
from .main_arg_signature import MainArgSignature
from .main_arg_signature_args_item import MainArgSignatureArgsItem
from .main_arg_signature_args_item_typ_type_0 import MainArgSignatureArgsItemTypType0
from .main_arg_signature_args_item_typ_type_1 import MainArgSignatureArgsItemTypType1
from .main_arg_signature_args_item_typ_type_2 import MainArgSignatureArgsItemTypType2
from .main_arg_signature_args_item_typ_type_2_list import MainArgSignatureArgsItemTypType2List
from .new_schedule import NewSchedule
from .new_schedule_args import NewScheduleArgs
from .new_token import NewToken
from .new_user import NewUser
from .preview import Preview
from .preview_args import PreviewArgs
from .preview_language import PreviewLanguage
from .preview_schedule_json_body import PreviewScheduleJsonBody
from .python_to_jsonschema_response_200 import PythonToJsonschemaResponse200
from .python_to_jsonschema_response_200_args_item import PythonToJsonschemaResponse200ArgsItem
from .python_to_jsonschema_response_200_args_item_typ_type_0 import PythonToJsonschemaResponse200ArgsItemTypType0
from .python_to_jsonschema_response_200_args_item_typ_type_1 import PythonToJsonschemaResponse200ArgsItemTypType1
from .python_to_jsonschema_response_200_args_item_typ_type_2 import PythonToJsonschemaResponse200ArgsItemTypType2
from .python_to_jsonschema_response_200_args_item_typ_type_2_list import (
    PythonToJsonschemaResponse200ArgsItemTypType2List,
)
from .queued_job import QueuedJob
from .queued_job_args import QueuedJobArgs
from .queued_job_flow_status import QueuedJobFlowStatus
from .queued_job_flow_status_failure_module import QueuedJobFlowStatusFailureModule
from .queued_job_flow_status_failure_module_type import QueuedJobFlowStatusFailureModuleType
from .queued_job_flow_status_modules_item import QueuedJobFlowStatusModulesItem
from .queued_job_flow_status_modules_item_type import QueuedJobFlowStatusModulesItemType
from .queued_job_job_kind import QueuedJobJobKind
from .queued_job_language import QueuedJobLanguage
from .queued_job_raw_flow import QueuedJobRawFlow
from .queued_job_raw_flow_failure_module import QueuedJobRawFlowFailureModule
from .queued_job_raw_flow_failure_module_input_transform import QueuedJobRawFlowFailureModuleInputTransform
from .queued_job_raw_flow_failure_module_input_transform_additional_property import (
    QueuedJobRawFlowFailureModuleInputTransformAdditionalProperty,
)
from .queued_job_raw_flow_failure_module_input_transform_additional_property_type import (
    QueuedJobRawFlowFailureModuleInputTransformAdditionalPropertyType,
)
from .queued_job_raw_flow_failure_module_value import QueuedJobRawFlowFailureModuleValue
from .queued_job_raw_flow_failure_module_value_language import QueuedJobRawFlowFailureModuleValueLanguage
from .queued_job_raw_flow_failure_module_value_type import QueuedJobRawFlowFailureModuleValueType
from .queued_job_raw_flow_modules_item import QueuedJobRawFlowModulesItem
from .queued_job_raw_flow_modules_item_input_transform import QueuedJobRawFlowModulesItemInputTransform
from .queued_job_raw_flow_modules_item_input_transform_additional_property import (
    QueuedJobRawFlowModulesItemInputTransformAdditionalProperty,
)
from .queued_job_raw_flow_modules_item_input_transform_additional_property_type import (
    QueuedJobRawFlowModulesItemInputTransformAdditionalPropertyType,
)
from .queued_job_raw_flow_modules_item_value import QueuedJobRawFlowModulesItemValue
from .queued_job_raw_flow_modules_item_value_language import QueuedJobRawFlowModulesItemValueLanguage
from .queued_job_raw_flow_modules_item_value_type import QueuedJobRawFlowModulesItemValueType
from .refresh_token_json_body import RefreshTokenJsonBody
from .remove_granular_acls_json_body import RemoveGranularAclsJsonBody
from .remove_granular_acls_kind import RemoveGranularAclsKind
from .remove_user_to_group_json_body import RemoveUserToGroupJsonBody
from .resource import Resource
from .resource_extra_perms import ResourceExtraPerms
from .resource_type import ResourceType
from .resource_value import ResourceValue
from .run_flow_by_path_json_body import RunFlowByPathJsonBody
from .run_flow_preview_json_body import RunFlowPreviewJsonBody
from .run_flow_preview_json_body_args import RunFlowPreviewJsonBodyArgs
from .run_flow_preview_json_body_value import RunFlowPreviewJsonBodyValue
from .run_flow_preview_json_body_value_failure_module import RunFlowPreviewJsonBodyValueFailureModule
from .run_flow_preview_json_body_value_failure_module_input_transform import (
    RunFlowPreviewJsonBodyValueFailureModuleInputTransform,
)
from .run_flow_preview_json_body_value_failure_module_input_transform_additional_property import (
    RunFlowPreviewJsonBodyValueFailureModuleInputTransformAdditionalProperty,
)
from .run_flow_preview_json_body_value_failure_module_input_transform_additional_property_type import (
    RunFlowPreviewJsonBodyValueFailureModuleInputTransformAdditionalPropertyType,
)
from .run_flow_preview_json_body_value_failure_module_value import RunFlowPreviewJsonBodyValueFailureModuleValue
from .run_flow_preview_json_body_value_failure_module_value_language import (
    RunFlowPreviewJsonBodyValueFailureModuleValueLanguage,
)
from .run_flow_preview_json_body_value_failure_module_value_type import (
    RunFlowPreviewJsonBodyValueFailureModuleValueType,
)
from .run_flow_preview_json_body_value_modules_item import RunFlowPreviewJsonBodyValueModulesItem
from .run_flow_preview_json_body_value_modules_item_input_transform import (
    RunFlowPreviewJsonBodyValueModulesItemInputTransform,
)
from .run_flow_preview_json_body_value_modules_item_input_transform_additional_property import (
    RunFlowPreviewJsonBodyValueModulesItemInputTransformAdditionalProperty,
)
from .run_flow_preview_json_body_value_modules_item_input_transform_additional_property_type import (
    RunFlowPreviewJsonBodyValueModulesItemInputTransformAdditionalPropertyType,
)
from .run_flow_preview_json_body_value_modules_item_value import RunFlowPreviewJsonBodyValueModulesItemValue
from .run_flow_preview_json_body_value_modules_item_value_language import (
    RunFlowPreviewJsonBodyValueModulesItemValueLanguage,
)
from .run_flow_preview_json_body_value_modules_item_value_type import RunFlowPreviewJsonBodyValueModulesItemValueType
from .run_script_by_hash_json_body import RunScriptByHashJsonBody
from .run_script_by_path_json_body import RunScriptByPathJsonBody
from .run_script_preview_json_body import RunScriptPreviewJsonBody
from .run_script_preview_json_body_args import RunScriptPreviewJsonBodyArgs
from .run_script_preview_json_body_language import RunScriptPreviewJsonBodyLanguage
from .schedule import Schedule
from .schedule_args import ScheduleArgs
from .schedule_extra_perms import ScheduleExtraPerms
from .script import Script
from .script_args import ScriptArgs
from .script_extra_perms import ScriptExtraPerms
from .script_language import ScriptLanguage
from .script_schema import ScriptSchema
from .set_password_json_body import SetPasswordJsonBody
from .set_schedule_enabled_json_body import SetScheduleEnabledJsonBody
from .set_workspace_slack_json_body import SetWorkspaceSlackJsonBody
from .set_workspace_slack_json_body_bot import SetWorkspaceSlackJsonBodyBot
from .slack_token import SlackToken
from .slack_token_bot import SlackTokenBot
from .token_response import TokenResponse
from .truncated_token import TruncatedToken
from .update_flow_json_body import UpdateFlowJsonBody
from .update_flow_json_body_schema import UpdateFlowJsonBodySchema
from .update_flow_json_body_value import UpdateFlowJsonBodyValue
from .update_flow_json_body_value_failure_module import UpdateFlowJsonBodyValueFailureModule
from .update_flow_json_body_value_failure_module_input_transform import (
    UpdateFlowJsonBodyValueFailureModuleInputTransform,
)
from .update_flow_json_body_value_failure_module_input_transform_additional_property import (
    UpdateFlowJsonBodyValueFailureModuleInputTransformAdditionalProperty,
)
from .update_flow_json_body_value_failure_module_input_transform_additional_property_type import (
    UpdateFlowJsonBodyValueFailureModuleInputTransformAdditionalPropertyType,
)
from .update_flow_json_body_value_failure_module_value import UpdateFlowJsonBodyValueFailureModuleValue
from .update_flow_json_body_value_failure_module_value_language import UpdateFlowJsonBodyValueFailureModuleValueLanguage
from .update_flow_json_body_value_failure_module_value_type import UpdateFlowJsonBodyValueFailureModuleValueType
from .update_flow_json_body_value_modules_item import UpdateFlowJsonBodyValueModulesItem
from .update_flow_json_body_value_modules_item_input_transform import UpdateFlowJsonBodyValueModulesItemInputTransform
from .update_flow_json_body_value_modules_item_input_transform_additional_property import (
    UpdateFlowJsonBodyValueModulesItemInputTransformAdditionalProperty,
)
from .update_flow_json_body_value_modules_item_input_transform_additional_property_type import (
    UpdateFlowJsonBodyValueModulesItemInputTransformAdditionalPropertyType,
)
from .update_flow_json_body_value_modules_item_value import UpdateFlowJsonBodyValueModulesItemValue
from .update_flow_json_body_value_modules_item_value_language import UpdateFlowJsonBodyValueModulesItemValueLanguage
from .update_flow_json_body_value_modules_item_value_type import UpdateFlowJsonBodyValueModulesItemValueType
from .update_group_json_body import UpdateGroupJsonBody
from .update_resource_json_body import UpdateResourceJsonBody
from .update_resource_json_body_value import UpdateResourceJsonBodyValue
from .update_resource_type_json_body import UpdateResourceTypeJsonBody
from .update_schedule_json_body import UpdateScheduleJsonBody
from .update_schedule_json_body_args import UpdateScheduleJsonBodyArgs
from .update_user_json_body import UpdateUserJsonBody
from .update_variable_json_body import UpdateVariableJsonBody
from .user import User
from .user_workspace_list import UserWorkspaceList
from .user_workspace_list_workspaces_item import UserWorkspaceListWorkspacesItem
from .validate_id_json_body import ValidateIdJsonBody
from .validate_username_json_body import ValidateUsernameJsonBody
from .whoami_response_200 import WhoamiResponse200
from .whois_response_200 import WhoisResponse200
from .worker_ping import WorkerPing
from .workspace import Workspace
from .workspace_invite import WorkspaceInvite



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.flow_value_failure_module_value_language import FlowValueFailureModuleValueLanguage
from ..models.flow_value_failure_module_value_type import FlowValueFailureModuleValueType
from ..types import UNSET, Unset

T = TypeVar("T", bound="FlowValueFailureModuleValue")


@attr.s(auto_attribs=True)
class FlowValueFailureModuleValue:
    """ """

    type: FlowValueFailureModuleValueType
    path: Union[Unset, str] = UNSET
    content: Union[Unset, str] = UNSET
    language: Union[Unset, FlowValueFailureModuleValueLanguage] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        path = self.path
        content = self.content
        language: Union[Unset, str] = UNSET
        if not isinstance(self.language, Unset):
            language = self.language.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
            }
        )
        if path is not UNSET:
            field_dict["path"] = path
        if content is not UNSET:
            field_dict["content"] = content
        if language is not UNSET:
            field_dict["language"] = language

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = FlowValueFailureModuleValueType(d.pop("type"))

        path = d.pop("path", UNSET)

        content = d.pop("content", UNSET)

        language: Union[Unset, FlowValueFailureModuleValueLanguage] = UNSET
        _language = d.pop("language", UNSET)
        if not isinstance(_language, Unset):
            language = FlowValueFailureModuleValueLanguage(_language)

        flow_value_failure_module_value = cls(
            type=type,
            path=path,
            content=content,
            language=language,
        )

        flow_value_failure_module_value.additional_properties = d
        return flow_value_failure_module_value

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.queued_job_flow_status_failure_module import QueuedJobFlowStatusFailureModule
from ..models.queued_job_flow_status_modules_item import QueuedJobFlowStatusModulesItem

T = TypeVar("T", bound="QueuedJobFlowStatus")


@attr.s(auto_attribs=True)
class QueuedJobFlowStatus:
    """ """

    step: int
    modules: List[QueuedJobFlowStatusModulesItem]
    failure_module: QueuedJobFlowStatusFailureModule
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        step = self.step
        modules = []
        for modules_item_data in self.modules:
            modules_item = modules_item_data.to_dict()

            modules.append(modules_item)

        failure_module = self.failure_module.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "step": step,
                "modules": modules,
                "failure_module": failure_module,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        step = d.pop("step")

        modules = []
        _modules = d.pop("modules")
        for modules_item_data in _modules:
            modules_item = QueuedJobFlowStatusModulesItem.from_dict(modules_item_data)

            modules.append(modules_item)

        failure_module = QueuedJobFlowStatusFailureModule.from_dict(d.pop("failure_module"))

        queued_job_flow_status = cls(
            step=step,
            modules=modules,
            failure_module=failure_module,
        )

        queued_job_flow_status.additional_properties = d
        return queued_job_flow_status

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.list_users_as_super_admin_response_200_item_login_type import (
    ListUsersAsSuperAdminResponse200ItemLoginType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="ListUsersAsSuperAdminResponse200Item")


@attr.s(auto_attribs=True)
class ListUsersAsSuperAdminResponse200Item:
    """ """

    email: str
    login_type: ListUsersAsSuperAdminResponse200ItemLoginType
    super_admin: bool
    verified: bool
    name: Union[Unset, str] = UNSET
    company: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        login_type = self.login_type.value

        super_admin = self.super_admin
        verified = self.verified
        name = self.name
        company = self.company

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "login_type": login_type,
                "super_admin": super_admin,
                "verified": verified,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if company is not UNSET:
            field_dict["company"] = company

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        login_type = ListUsersAsSuperAdminResponse200ItemLoginType(d.pop("login_type"))

        super_admin = d.pop("super_admin")

        verified = d.pop("verified")

        name = d.pop("name", UNSET)

        company = d.pop("company", UNSET)

        list_users_as_super_admin_response_200_item = cls(
            email=email,
            login_type=login_type,
            super_admin=super_admin,
            verified=verified,
            name=name,
            company=company,
        )

        list_users_as_super_admin_response_200_item.additional_properties = d
        return list_users_as_super_admin_response_200_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CompletedJobRawFlowModulesItemValueType(str, Enum):
    SCRIPT = "script"
    FLOW = "flow"
    RAWSCRIPT = "rawscript"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class GetAuditLogResponse200Operation(str, Enum):
    JOBSRUN = "jobs.run"
    SCRIPTSCREATE = "scripts.create"
    SCRIPTSUPDATE = "scripts.update"
    USERSCREATE = "users.create"
    USERSDELETE = "users.delete"
    USERSSETPASSWORD = "users.setpassword"
    USERSUPDATE = "users.update"
    USERSLOGIN = "users.login"
    USERSTOKENCREATE = "users.token.create"
    USERSTOKENDELETE = "users.token.delete"
    VARIABLESCREATE = "variables.create"
    VARIABLESDELETE = "variables.delete"
    VARIABLESUPDATE = "variables.update"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.get_script_by_hash_response_200_extra_perms import GetScriptByHashResponse200ExtraPerms
from ..models.get_script_by_hash_response_200_language import GetScriptByHashResponse200Language
from ..models.get_script_by_hash_response_200_schema import GetScriptByHashResponse200Schema
from ..types import UNSET, Unset

T = TypeVar("T", bound="GetScriptByHashResponse200")


@attr.s(auto_attribs=True)
class GetScriptByHashResponse200:
    """ """

    hash_: str
    path: str
    summary: str
    content: str
    created_by: str
    created_at: datetime.datetime
    archived: bool
    deleted: bool
    is_template: bool
    extra_perms: GetScriptByHashResponse200ExtraPerms
    language: GetScriptByHashResponse200Language
    workspace_id: Union[Unset, str] = UNSET
    parent_hashes: Union[Unset, List[str]] = UNSET
    description: Union[Unset, str] = UNSET
    schema: Union[Unset, GetScriptByHashResponse200Schema] = UNSET
    lock: Union[Unset, str] = UNSET
    lock_error_logs: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        hash_ = self.hash_
        path = self.path
        summary = self.summary
        content = self.content
        created_by = self.created_by
        created_at = self.created_at.isoformat()

        archived = self.archived
        deleted = self.deleted
        is_template = self.is_template
        extra_perms = self.extra_perms.to_dict()

        language = self.language.value

        workspace_id = self.workspace_id
        parent_hashes: Union[Unset, List[str]] = UNSET
        if not isinstance(self.parent_hashes, Unset):
            parent_hashes = self.parent_hashes

        description = self.description
        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        lock = self.lock
        lock_error_logs = self.lock_error_logs

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "hash": hash_,
                "path": path,
                "summary": summary,
                "content": content,
                "created_by": created_by,
                "created_at": created_at,
                "archived": archived,
                "deleted": deleted,
                "is_template": is_template,
                "extra_perms": extra_perms,
                "language": language,
            }
        )
        if workspace_id is not UNSET:
            field_dict["workspace_id"] = workspace_id
        if parent_hashes is not UNSET:
            field_dict["parent_hashes"] = parent_hashes
        if description is not UNSET:
            field_dict["description"] = description
        if schema is not UNSET:
            field_dict["schema"] = schema
        if lock is not UNSET:
            field_dict["lock"] = lock
        if lock_error_logs is not UNSET:
            field_dict["lock_error_logs"] = lock_error_logs

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        hash_ = d.pop("hash")

        path = d.pop("path")

        summary = d.pop("summary")

        content = d.pop("content")

        created_by = d.pop("created_by")

        created_at = isoparse(d.pop("created_at"))

        archived = d.pop("archived")

        deleted = d.pop("deleted")

        is_template = d.pop("is_template")

        extra_perms = GetScriptByHashResponse200ExtraPerms.from_dict(d.pop("extra_perms"))

        language = GetScriptByHashResponse200Language(d.pop("language"))

        workspace_id = d.pop("workspace_id", UNSET)

        parent_hashes = cast(List[str], d.pop("parent_hashes", UNSET))

        description = d.pop("description", UNSET)

        schema: Union[Unset, GetScriptByHashResponse200Schema] = UNSET
        _schema = d.pop("schema", UNSET)
        if not isinstance(_schema, Unset):
            schema = GetScriptByHashResponse200Schema.from_dict(_schema)

        lock = d.pop("lock", UNSET)

        lock_error_logs = d.pop("lock_error_logs", UNSET)

        get_script_by_hash_response_200 = cls(
            hash_=hash_,
            path=path,
            summary=summary,
            content=content,
            created_by=created_by,
            created_at=created_at,
            archived=archived,
            deleted=deleted,
            is_template=is_template,
            extra_perms=extra_perms,
            language=language,
            workspace_id=workspace_id,
            parent_hashes=parent_hashes,
            description=description,
            schema=schema,
            lock=lock,
            lock_error_logs=lock_error_logs,
        )

        get_script_by_hash_response_200.additional_properties = d
        return get_script_by_hash_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.list_completed_jobs_response_200_item import ListCompletedJobsResponse200Item
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    workspace: str,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
    script_path_exact: Union[Unset, str] = UNSET,
    script_path_start: Union[Unset, str] = UNSET,
    script_hash: Union[Unset, str] = UNSET,
    created_before: Union[Unset, datetime.datetime] = UNSET,
    created_after: Union[Unset, datetime.datetime] = UNSET,
    success: Union[Unset, bool] = UNSET,
    job_kinds: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/w/{workspace}/jobs/completed/list".format(client.base_url, workspace=workspace)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_created_before: Union[Unset, str] = UNSET
    if not isinstance(created_before, Unset):
        json_created_before = created_before.isoformat()

    json_created_after: Union[Unset, str] = UNSET
    if not isinstance(created_after, Unset):
        json_created_after = created_after.isoformat()

    params: Dict[str, Any] = {
        "order_desc": order_desc,
        "created_by": created_by,
        "parent_job": parent_job,
        "script_path_exact": script_path_exact,
        "script_path_start": script_path_start,
        "script_hash": script_hash,
        "created_before": json_created_before,
        "created_after": json_created_after,
        "success": success,
        "job_kinds": job_kinds,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[ListCompletedJobsResponse200Item]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = ListCompletedJobsResponse200Item.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[ListCompletedJobsResponse200Item]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    workspace: str,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
    script_path_exact: Union[Unset, str] = UNSET,
    script_path_start: Union[Unset, str] = UNSET,
    script_hash: Union[Unset, str] = UNSET,
    created_before: Union[Unset, datetime.datetime] = UNSET,
    created_after: Union[Unset, datetime.datetime] = UNSET,
    success: Union[Unset, bool] = UNSET,
    job_kinds: Union[Unset, str] = UNSET,
) -> Response[List[ListCompletedJobsResponse200Item]]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        order_desc=order_desc,
        created_by=created_by,
        parent_job=parent_job,
        script_path_exact=script_path_exact,
        script_path_start=script_path_start,
        script_hash=script_hash,
        created_before=created_before,
        created_after=created_after,
        success=success,
        job_kinds=job_kinds,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    workspace: str,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
    script_path_exact: Union[Unset, str] = UNSET,
    script_path_start: Union[Unset, str] = UNSET,
    script_hash: Union[Unset, str] = UNSET,
    created_before: Union[Unset, datetime.datetime] = UNSET,
    created_after: Union[Unset, datetime.datetime] = UNSET,
    success: Union[Unset, bool] = UNSET,
    job_kinds: Union[Unset, str] = UNSET,
) -> Optional[List[ListCompletedJobsResponse200Item]]:
    """ """

    return sync_detailed(
        client=client,
        workspace=workspace,
        order_desc=order_desc,
        created_by=created_by,
        parent_job=parent_job,
        script_path_exact=script_path_exact,
        script_path_start=script_path_start,
        script_hash=script_hash,
        created_before=created_before,
        created_after=created_after,
        success=success,
        job_kinds=job_kinds,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    workspace: str,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
    script_path_exact: Union[Unset, str] = UNSET,
    script_path_start: Union[Unset, str] = UNSET,
    script_hash: Union[Unset, str] = UNSET,
    created_before: Union[Unset, datetime.datetime] = UNSET,
    created_after: Union[Unset, datetime.datetime] = UNSET,
    success: Union[Unset, bool] = UNSET,
    job_kinds: Union[Unset, str] = UNSET,
) -> Response[List[ListCompletedJobsResponse200Item]]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        order_desc=order_desc,
        created_by=created_by,
        parent_job=parent_job,
        script_path_exact=script_path_exact,
        script_path_start=script_path_start,
        script_hash=script_hash,
        created_before=created_before,
        created_after=created_after,
        success=success,
        job_kinds=job_kinds,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    workspace: str,
    order_desc: Union[Unset, bool] = UNSET,
    created_by: Union[Unset, str] = UNSET,
    parent_job: Union[Unset, str] = UNSET,
    script_path_exact: Union[Unset, str] = UNSET,
    script_path_start: Union[Unset, str] = UNSET,
    script_hash: Union[Unset, str] = UNSET,
    created_before: Union[Unset, datetime.datetime] = UNSET,
    created_after: Union[Unset, datetime.datetime] = UNSET,
    success: Union[Unset, bool] = UNSET,
    job_kinds: Union[Unset, str] = UNSET,
) -> Optional[List[ListCompletedJobsResponse200Item]]:
    """ """

    return (
        await asyncio_detailed(
            client=client,
            workspace=workspace,
            order_desc=order_desc,
            created_by=created_by,
            parent_job=parent_job,
            script_path_exact=script_path_exact,
            script_path_start=script_path_start,
            script_hash=script_hash,
            created_before=created_before,
            created_after=created_after,
            success=success,
            job_kinds=job_kinds,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.deno_to_jsonschema_response_200_args_item import DenoToJsonschemaResponse200ArgsItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="DenoToJsonschemaResponse200")


@attr.s(auto_attribs=True)
class DenoToJsonschemaResponse200:
    """ """

    star_args: bool
    args: List[DenoToJsonschemaResponse200ArgsItem]
    star_kwargs: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        star_args = self.star_args
        args = []
        for args_item_data in self.args:
            args_item = args_item_data.to_dict()

            args.append(args_item)

        star_kwargs = self.star_kwargs

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "star_args": star_args,
                "args": args,
            }
        )
        if star_kwargs is not UNSET:
            field_dict["star_kwargs"] = star_kwargs

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        star_args = d.pop("star_args")

        args = []
        _args = d.pop("args")
        for args_item_data in _args:
            args_item = DenoToJsonschemaResponse200ArgsItem.from_dict(args_item_data)

            args.append(args_item)

        star_kwargs = d.pop("star_kwargs", UNSET)

        deno_to_jsonschema_response_200 = cls(
            star_args=star_args,
            args=args,
            star_kwargs=star_kwargs,
        )

        deno_to_jsonschema_response_200.additional_properties = d
        return deno_to_jsonschema_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class PythonToJsonschemaResponse200ArgsItemTypType2List(str, Enum):
    STR = "str"
    FLOAT = "float"
    INT = "int"
    EMAIL = "email"

    def __str__(self) -> str:
        return str(self.value)
